@@ -1467,9 +1467,9 @@ void maketree()
   if ( jumb < njumble)
     return;
   if (progress) {
-    printf("\n\nOutput written to file \"%s\"\n\n", outfilename);
+    printf("\nOutput written to file \"%s\"\n", outfilename);
     if (trout)
-      printf("Tree also written onto file \"%s\"\n\n", outtreename);
+      printf("\nTree also written onto file \"%s\"\n", outtreename);
   }
   freeview(&curtree, nonodes2);
   if (!usertree) {
@@ -1527,7 +1527,7 @@ int main(int argc, Char *argv[])
   fixmacfile(outfilename);
   fixmacfile(outtreename);
 #endif
-  printf("Done.\n\n");
+  printf("\nDone.\n\n");
 #ifdef WIN32
   phyRestoreConsoleAttributes();
 #endif
