@@ -199,6 +199,7 @@ void getdata()
   cntrast = (phenotype3 **)Malloc((long)spp*sizeof(phenotype3 *));
   ssqcont = (phenotype3 *)Malloc((long)spp*sizeof(phenotype3 *));
   contnum = spp-1;
+  //printf("%4ld Populations, %4ld Characters\n", spp, chars);
   for (i = 0; i < spp; i++) {
     scan_eoln(infile);
     initname(i);
@@ -213,13 +214,15 @@ void getdata()
       }
     }
     else sample[i] = 1;
+    //printf("name: %s count: %ld\n", nayme[i], sample[i]);
     if (printdata)
       for(j = 0; j < nmlngth; j++)
         putc(nayme[i][j], outfile);
     x[i] = (phenotype3 *)Malloc((long)sample[i]*sizeof(phenotype3));
     cntrast[i] = (phenotype3 *)Malloc((long)(sample[i]*sizeof(phenotype3)));
     ssqcont[i] = (double *)Malloc((long)(sample[i]*sizeof(double)));
-    for (k = 0; k <= sample[i]-1; k++) {
+    //for (k = 0; k <= sample[i]-1; k++) {
+    for (k = 0; k < sample[i]; k++) {
       x[i][k] = (phenotype3)Malloc((long)chars*sizeof(double));
       cntrast[i][k] = (phenotype3)Malloc((long)chars*sizeof(double));
       for (j = 1; j <= chars; j++) {
@@ -229,6 +232,7 @@ void getdata()
           printf("Error in input file at species %ld\n", i+1);
           exxit(-1);
         }
+        //printf("i: %ld, j: %ld, k: %ld, val: %9.5f\n", i,j,k, x[i][k][j - 1]);
         if (printdata) {
           fprintf(outfile, " %9.5f", x[i][k][j - 1]);
           if (j % 6 == 0) {
@@ -238,6 +242,10 @@ void getdata()
           }
         }
       }
+      // got all the data we need for that member,
+      // read the next line if we still have more members to define
+      if (k != sample[i]-1)
+        scan_eoln(infile);
     }
     if (printdata)
       putc('\n', outfile);
