@@ -553,8 +553,7 @@ void dnadist_sitecombine()
     j = i + 1;
     tied = true;
     while (j <= sites && tied) {
-      tied = (oldweight[alias[i - 1] - 1] == oldweight[alias[j - 1] - 1] &&
-              category[alias[i - 1] - 1] == category[alias[j - 1] - 1]);
+      tied = (category[alias[i - 1] - 1] == category[alias[j - 1] - 1]);
       k = 1;
       while (k <= spp && tied) {
         tied = (tied &&
@@ -590,8 +589,6 @@ void dnadist_sitescrunch()
           found = (ally[alias[j - 1] - 1] == alias[j - 1]);
           j++;
           completed = (j > sites);
-          if (j <= sites)
-            completed = (oldweight[alias[j - 1] - 1] == 0);
         } while (!(found || completed));
         if (found) {
           j--;
@@ -617,6 +614,7 @@ void makeweights()
   for (i = 1; i <= sites; i++) {
     alias[i - 1] = i;
     ally[i - 1] = i;
+    location[i - 1] = 0;
     weight[i - 1] = 0;
   }
   dnadist_sitesort();
@@ -624,7 +622,7 @@ void makeweights()
   dnadist_sitescrunch();
   endsite = 0;
   for (i = 1; i <= sites; i++) {
-    if (ally[i - 1] == i && oldweight[i - 1] > 0)
+    if (ally[i - 1] == i)
       endsite++;
   }
   for (i = 1; i <= endsite; i++)
@@ -638,7 +636,8 @@ void makeweights()
   for (i = 0; i < categs; i++)
     rate[i] *= weightsum / sumrates;
   for (i = 0; i < sites; i++)
-    weight[location[ally[i] - 1] - 1] += oldweight[i];
+    if (oldweight[i] > 0)
+      weight[location[ally[i] - 1] - 1] += oldweight[i];
 }  /* makeweights */
 
 
