@@ -596,20 +596,20 @@ void makeweights()
 
   for (i = 1; i <= sites; i++) {
     alias[i - 1] = i;
-    ally[i - 1] = 0;
+    ally[i - 1] = i;
     aliasweight[i - 1] = weight[i - 1];
     location[i - 1] = 0;
   }
   sitesort2   (sites, aliasweight);
   sitecombine2(sites, aliasweight);
   sitescrunch2(sites, 1, 2, aliasweight);
+  endsite = 0;
   for (i = 1; i <= sites; i++) {
-    if (aliasweight[i - 1] > 0)
-      endsite = i;
+    if (ally[i - 1] == i)
+      endsite++;
   }
   for (i = 1; i <= endsite; i++) {
     location[alias[i - 1] - 1] = i;
-    ally[alias[i - 1] - 1] = alias[i - 1];
   }
   term = (double **) Malloc( endsite * sizeof(double *));
   for (i = 0; i < endsite; i++)
