@@ -8,8 +8,6 @@
    Permission is granted to copy and use this program provided no fee is
    charged for it and provided that this copyright notice is not removed. */
 
-#define overr           4
-#define which           1
 #define maxsz           999   /* size of pointer array for the undo trees */
                               /* this can be large without eating memory */
 
@@ -429,6 +427,7 @@ void getoptions()
 #ifdef WIN32
     phyFillScreenColor();
 #endif
+    fflush(stdout);
     scanf("%c%*[^\n]", &ch);
     getchar();
     uppercase(&ch);
@@ -1429,6 +1428,7 @@ void yourtree()
 #ifdef WIN32
         phyFillScreenColor();
 #endif
+        fflush(stdout);
         scanf("%c%*[^\n]", &ch);
         getchar();
         if (ch == '\n')
@@ -1506,7 +1506,8 @@ void buildtree()
     break;
 
   case use:
-    openfile(&intree,intreename,"input tree file", "r",progname,intreename);
+    /* Open in binary: ftell() is broken for UNIX line-endings under WIN32 */
+    openfile(&intree,intreename,"input tree file", "rb",progname,intreename);
     names = (boolean *)Malloc(spp*sizeof(boolean));
     firsttree = true; 
     nodep = NULL;
@@ -1696,6 +1697,7 @@ void rearrange()
 #ifdef WIN32
           phyFillScreenColor();
 #endif
+          fflush(stdout);
           scanf("%c%*[^\n]", &ch);
           getchar();
           if (ch == '\n')
@@ -2146,6 +2148,7 @@ void redisplay()
 #ifdef WIN32
     phyFillScreenColor();
 #endif
+    fflush(stdout);
     scanf("%c%*[^\n]", &ch);
     getchar();
     uppercase(&ch); 
@@ -2246,6 +2249,7 @@ void redisplay()
 #ifdef WIN32
     phyFillScreenColor();
 #endif
+    fflush(stdout);
     scanf("%c%*[^\n]", &ch);
     getchar();
     if (ch == 'Y' || ch == 'y')
