@@ -1496,12 +1496,12 @@ void maketree()
   }
   if (jumb == njumble) {
     if (progress) {
-      printf("\nOutput written to file \"%s\"\n\n", outfilename);
+      printf("\nOutput written to file \"%s\"\n", outfilename);
       if (trout) {
-        printf("Tree");
+        printf("\nTree");
         if ((usertree && numtrees > 1) || (!usertree && nextree != 2))
           printf("s");
-        printf(" also written onto file \"%s\"\n\n", outtreename);
+        printf(" also written onto file \"%s\"\n", outtreename);
       }
     }
   }
@@ -1629,7 +1629,7 @@ int main(int argc, Char *argv[])
   fixmacfile(outtreename);
 #endif
   if (progress)
-    printf("Done.\n\n");
+    printf("\nDone.\n\n");
 #ifdef WIN32
   phyRestoreConsoleAttributes();
 #endif
