@@ -419,7 +419,7 @@ void supplement(node *r)
   /* determine minimum number of steps more which will
      be added when rest of species are put in tree */
   long i, j, k, has, sum;
-  boolean addedmayhave, nonaddedhave, doneadded;
+  boolean addedmayhave, nonaddedhave;
 
   for (i = 0; i < endsite; i++) {
     nonaddedhave = 0;;
