@@ -33,7 +33,7 @@ void   maketree(void);
 
 Char infilename[FNMLNGTH], outfilename[FNMLNGTH], outtreename[FNMLNGTH],  weightfilename[FNMLNGTH], ancfilename[FNMLNGTH];
 node *root;
-long howmany, howoften, col, msets, ith;
+long howmanny, howoften, col, msets, ith;
 boolean weights, thresh, ancvar, questions, dollo, simple, trout,
                progress, treeprint, stepbox, ancseq,
                mulsets, firstset, justwts;
@@ -70,7 +70,7 @@ void getoptions()
   fprintf(outfile, " branch-and-bound to find all");
   fprintf(outfile, " most parsimonious trees\n\n");
   howoften = often;
-  howmany = many;
+  howmanny = many;
   simple = true;
   thresh = false;
   threshold = spp;
@@ -93,7 +93,7 @@ void getoptions()
     printf("Settings for this run:\n");
     printf("  P                     Parsimony method?  %s\n",
            (dollo ? "Dollo" : "Polymorphism"));
-    printf("  H        How many groups of %4ld trees:%6ld\n",howoften,howmany);
+    printf("  H        How many groups of %4ld trees:%6ld\n",howoften,howmanny);
     printf("  F        How often to report, in trees:%5ld\n",howoften);
     printf("  S           Branch and bound is simple?  %s\n",
            (simple ? "Yes" : "No.  Reconsiders order of species"));
@@ -136,6 +136,7 @@ void getoptions()
 #ifdef WIN32
     phyFillScreenColor();
 #endif
+    fflush(stdout);
     scanf("%c%*[^\n]", &ch);
     getchar();
     uppercase(&ch);
@@ -149,7 +150,7 @@ void getoptions()
         break;
 
         case 'H':
-          inithowmany(&howmany, howoften);
+          inithowmany(&howmanny, howoften);
           break;
 
         case 'F':
@@ -184,6 +185,7 @@ void getoptions()
 #ifdef WIN32
             phyFillScreenColor();
 #endif
+            fflush(stdout);
             scanf("%c%*[^\n]", &ch2);
             getchar();
             if (ch2 == '\n')
@@ -424,7 +426,7 @@ void addtraverse(node *a, node *b, node *c, placeptr place,
   if (examined == howoften) {
     examined = 0;
     mults++;
-    if (mults == howmany)
+    if (mults == howmanny)
       done = true;
     if (progress) {
       printf("%6ld",mults);
