@@ -25,11 +25,11 @@ HDC hdc;
 #ifdef QUICKC
 extern struct videoconfig myscreen;
 #endif
-
+/*
 #ifdef OSX_CARBON
 #include <Carbon/Carbon.h>
 #endif
-
+*/
 #include "draw.h"
 #include "phylip.h"
 
@@ -53,7 +53,7 @@ extern node *root;
 extern long    nmoves, oldpictint ;
 extern long    rootmatrix[51][51];
 extern long    strpbottom,strptop,strpwide,strpdeep;
-extern boolean dotmatrix, empty, previewing;
+extern boolean dotmatrix, empty;
 extern double  ynow, ysize, xsize, yunitspercm;
 extern FILE          *plotfile;
 extern plottertype   plotter;
@@ -73,7 +73,7 @@ extern double labelline,linewidth,oldxhigh,oldxlow,oldyhigh,oldylow,
 /* func. protocol added for vrml - danieyek 981111 */
 
 extern long          strpdiv,hpresolution;
-extern boolean       preview,pictbold,pictitalic,
+extern boolean       pictbold,pictitalic,
   pictshadow,pictoutline;
 extern double        expand,xcorner,xnow,xscale,xunitspercm,
   ycorner,yscale,labelrotation,
@@ -82,7 +82,7 @@ extern double        expand,xcorner,xnow,xscale,xunitspercm,
 extern long          filesize;
 extern growth        grows;
 extern enum {yes,no} penchange,oldpenchange;
-extern plottertype   oldplotter,previewer;
+extern plottertype   oldplotter;
 extern char             resopts;
 extern winactiontype winaction;
 
@@ -173,7 +173,7 @@ void plotdot(long ix, long iy)
   case ibm:
   case other:
     break;
-  default:        /* cases xpreview and vrml not handled        */
+  default:        /* vrml not handled        */
     break;
     /* code for making dot array for a new printer
       goes here */
@@ -335,36 +335,11 @@ void plot(pensttstype pen, double xabs, double yabs)
 
 /* remember to respect & translate for clipping region, clip{x,y}{0,1} */
 
-  if (!dotmatrix || previewing) {
+  if (!dotmatrix) {
     switch (plotter) {
 
-    case xpreview:
-      if (pen == pendown) {
-#ifdef X
-        XDrawLine(display,mainwin,gc1,(long)oldx,(long)(height-oldy),
-                                      (long)xabs,(long)(height-yabs));
-#endif
-      }
-      oldx = xabs;
-      oldy = yabs;
-      break;
-
-    case winpreview:
-#ifdef WIN32
-      if (pen == pendown) {
-        LineTo(hdc, (int) xabs, (int)(winheight-yabs)); 
-      }
-      else {
-        MoveToEx(hdc, (int) xabs, (int) (winheight-yabs), (LPPOINT) NULL); 
-      }
-#endif
-      break;
-
     case tek:
       if (pen == penup) {
-        if (previewing)
-          putchar('\035');
-        else
           putc('\035', plotfile);
       }
       ixnow = (long)floor(xabs + 0.5);
@@ -375,50 +350,26 @@ void plot(pensttstype pen, double xabs, double yabs)
       ylow = iynow & 31;
       if (!ebcdic) {
         if (yhigh != oldyhigh) {
-          if (previewing)
-            putchar(yhigh + 32);
-          else
             putc(yhigh + 32, plotfile);
         }
         if (ylow != oldylow || xhigh != oldxhigh) {
-          if (previewing)
-            putchar(ylow + 96);
-          else
             putc(ylow + 96, plotfile);
         }
         if (xhigh != oldxhigh) {
-          if (previewing)
-            putchar(xhigh + 32);
-          else
             putc(xhigh + 32, plotfile);
         }
-        if (previewing)
-          putchar(xlow + 64);
-        else
-          putc(xlow + 64, plotfile);
+        putc(xlow + 64, plotfile);
       } else {  /* DLS/JMH -- for systems that use EBCDIC coding */
         if (yhigh != oldyhigh) {
-          if (previewing)
-            putchar(eb[yhigh + 32]);
-          else
             putc(eb[yhigh + 32], plotfile);
         }
         if (ylow != oldylow || xhigh != oldxhigh) {
-          if (previewing)
-            putchar(eb[ylow + 96]);
-          else
             putc(eb[ylow + 96], plotfile);
         }
         if (xhigh != oldxhigh) {
-          if (previewing)
-            putchar(eb[xhigh + 32]);
-          else
             putc(eb[xhigh + 32], plotfile);
         }
-        if (previewing)
-          putchar(eb[xlow + 64]);
-        else
-          putc(eb[xlow + 64], plotfile);
+        putc(eb[xlow + 64], plotfile);
       }
 
       oldxhigh = xhigh;
@@ -529,14 +480,37 @@ void plot(pensttstype pen, double xabs, double yabs)
       if (pen == pendown){
         /* If there's NO possibility that the line interesects the page, 
          * leave it out. Otherwise, let postscript clip it to the page. */
+         /*
+          printf("xabs: %f\n", xabs);
+          printf("oldx: %f\n", oldx);
+          printf("clipx0: %f\n", clipx0);
+          printf("clipx1: %f\n", clipx1);
+          printf("xunitspercm: %f\n", xunitspercm);
+          printf("yabs: %f\n", yabs);
+          printf("oldy: %f\n", oldy);
+          printf("clipy0: %f\n", clipy0);
+          printf("clipy1: %f\n", clipy1);
+          printf("yunitspercm: %f\n", yunitspercm);
+          */
+         /*  this is broken, but now irrelevant for preview
           if (!((xabs > clipx1*xunitspercm &&  oldx > clipx1*xunitspercm) ||
               (xabs < clipx0*xunitspercm &&  oldx < clipx0*xunitspercm) ||
               (yabs > clipy1*yunitspercm &&  oldy > clipy1*yunitspercm) ||
               (yabs < clipy0*yunitspercm &&  oldy < clipy0*yunitspercm)))
-            fprintf(plotfile, "%8.2f %8.2f %8.2f %8.2f l\n",
+              {
+              
+                    printf("line: %8.2f %8.2f %8.2f %8.2f\n",
                     oldx-(clipx0*xunitspercm), oldy-(clipy0*yunitspercm),
                     xabs-(clipx0*xunitspercm), yabs-(clipy0*yunitspercm));
+                    */
+                    fprintf(plotfile, "%8.2f %8.2f %8.2f %8.2f l\n",
+                    oldx-(clipx0*xunitspercm), oldy-(clipy0*yunitspercm),
+                    xabs-(clipx0*xunitspercm), yabs-(clipy0*yunitspercm));
+              /*      
+               }
+               */
         }
+        
         oldx     = xabs,
         oldy     = yabs;
       break;
@@ -656,34 +630,19 @@ void plot(pensttstype pen, double xabs, double yabs)
       newx = floor(xabs + 0.5);
       newy = fabs(floor(yabs + 0.5) - 479);
       if (pen == pendown) {
-        if (previewing) {
-          printf("P[");
-          pout((long)oldx);
-          putchar(',');
-          pout((long)oldy);
-          printf("]V[");
-          pout((long)newx);
-          putchar(',');
-          pout((long)newy);
-          putchar(']');
-        } else {
-          fprintf(plotfile, "P[");
-          pout((long)oldx);
-          putc(',', plotfile);
-          pout((long)oldy);
-          fprintf(plotfile, "]V[");
-          pout((long)newx);
-          putc(',', plotfile);
-          pout((long)newy);
-          putc(']', plotfile);
-        }
+        fprintf(plotfile, "P[");
+        pout((long)oldx);
+        putc(',', plotfile);
+        pout((long)oldy);
+        fprintf(plotfile, "]V[");
+        pout((long)newx);
+        putc(',', plotfile);
+        pout((long)newy);
+        putc(']', plotfile);
         nmoves++;
         if (nmoves == 3) {
           nmoves = 0;
-          if (previewing)
-            putchar('\n');
-          else
-            putc('\n', plotfile);
+          putc('\n', plotfile);
         }
       }
       oldx = newx;
@@ -1263,6 +1222,7 @@ void write_bmp_header (FILE *plotfile,int width,int height)
    *  write a 1-bit image header
    *
    */
+  //putc('T', testBMPfile);
 
   byte r1[2],g1[2],b1[2] ;
 
@@ -1397,14 +1357,16 @@ void translate_stripe_to_bmp(striptype *stripe, byte *full_pic,
                   (padded_width * DEFAULT_STRIPE_HEIGHT))
     - (padded_width * last_stripe_offset)
     + pad_size ;
+  //testBMPfile= fopen("testBMPfile","ab");
 
   for (j = div; j >= 0; j--) {
     for (i = 0; i < width; i++) {
-      full_pic[offset +        
-              (((div-j) * padded_width) 
-               + (width-i))] = (byte) (*stripe)[j][i];
+      full_pic[offset + (((div-j) * padded_width) + (width-i))] = (byte) (*stripe)[j][i];
+      //putc((byte) (*stripe)[j][i], testBMPfile);
+
       (*total_bytes)++ ;
     }
+    //fclose(testBMPfile);
 
     /* Take into account the padding */
     (*total_bytes) += pad_size ;
@@ -1415,9 +1377,11 @@ void translate_stripe_to_bmp(striptype *stripe, byte *full_pic,
 void write_full_pic(byte *full_pic, int total_bytes)
 {
   int i ;
+
   for (i = 0; i < total_bytes; i++) {
     putc (full_pic[i], plotfile);
   }
+  
 }  /* write_full_pic */
 
 
@@ -1561,223 +1525,3 @@ double computeAngle(double oldx, double oldy, double newx, double newy)
   return angle;
 }  /* computeAngle */
 
-#ifdef WIN32
-#include <windows.h>
-
-/*********************  Prototypes  ***********************/
-
-LRESULT WINAPI MainWndProc( HWND, UINT, WPARAM, LPARAM );
-LRESULT WINAPI AboutDlgProc( HWND, UINT, WPARAM, LPARAM );
-
-/*******************  Global Variables ********************/
-extern void winplotpreviewcore();
-HANDLE ghInstance;
-HPEN hPenTree, hPenLabel, hPenBackground, hPenOld; 
-
-/********************************************************************\
-*  Comments: Register window class, create and display the main      *
-*            window, and enter message loop.                         *
-\********************************************************************/
-
-winplotpreview()
-{
-   WNDCLASS wc;
-   MSG msg;
-   HWND hWnd;
-   int screenXres, screenYres, winXres, winYres;
-
-   winaction = quitnow;
-
-   wc.lpszClassName = "GenericAppClass";
-   wc.lpfnWndProc = MainWndProc;
-   wc.style = CS_OWNDC | CS_VREDRAW | CS_HREDRAW;
-   wc.hInstance = NULL;
-   wc.hIcon = LoadIcon( NULL, IDI_APPLICATION );
-   wc.hCursor = LoadCursor( NULL, IDC_ARROW );
-   wc.hbrBackground = (HBRUSH)( COLOR_WINDOW+1 );
-   wc.lpszMenuName = "GenericAppMenu";
-   wc.cbClsExtra = 0;
-   wc.cbWndExtra = 0;
-
-   RegisterClass( &wc );
-
-   ghInstance = NULL;
-
-   screenXres = GetSystemMetrics(SM_CXSCREEN);
-   winXres = (int)((float)(screenXres)*XWINPERCENT);
-   screenYres = GetSystemMetrics(SM_CYSCREEN);
-   winYres = (int)((float)(screenYres)*YWINPERCENT);
-
-   hWnd = CreateWindow( "GenericAppClass",
-      "Tree Preview",
-      WS_OVERLAPPEDWINDOW,
-      0,
-      0,
-      winXres,
-      winYres,
-      NULL,
-      NULL,
-      NULL,
-      NULL
-   );
-
-   ShowWindow( hWnd, SW_SHOWNORMAL );
-
-   while( GetMessage( &msg, NULL, 0, 0 ) ) {
-      TranslateMessage( &msg );
-      DispatchMessage( &msg );
-   }
-
-   return msg.wParam;
-}
-
-/*********************     *
-*                                                                    *
-* Comments: The following messages are processed                     *
-*                                                                    *
-*           WM_PAINT                                                 *
-*           WM_COMMAND                                               *
-*           WM_DESTROY                                               *
-*                                                                    *
-*                                                                    *
-\********************************************************************/
-
-LRESULT CALLBACK MainWndProc( HWND hWnd, UINT msg, WPARAM wParam,
-   LPARAM lParam )
-{
-   PAINTSTRUCT ps;
-   LOGBRUSH lb;
-   HBRUSH bgbrush; 
-   RECT lpRect;
-   int windowwidth, windowheight;
-
-   switch( msg ) {
-/**************************************************************\
-*     WM_ACTIVATE:                                             *
-\**************************************************************/
-
-      case WM_ACTIVATE:
-         if (wParam != WA_INACTIVE)
-            BringWindowToTop(hWnd);
-      break;
-
-/**************************************************************\
-*     WM_PAINT:                                                *
-\**************************************************************/
-
-      case WM_PAINT:
-         hdc = BeginPaint( hWnd, &ps );
-         /* Initialize the pen's brush. */
-         lb.lbStyle = BS_SOLID; 
-         lb.lbColor = RGB(0,0,0); 
-         lb.lbHatch = 0;
-         /* 2 pixel pen for the tree */
-         hPenTree = ExtCreatePen(PS_GEOMETRIC | PS_SOLID | PS_ENDCAP_ROUND,
-                            (DWORD)2, &lb, 0, NULL); 
-         /* 1 pixel pen for labels */
-         hPenLabel = ExtCreatePen(PS_GEOMETRIC | PS_SOLID | PS_ENDCAP_ROUND,
-                            (DWORD)1, &lb, 0, NULL); 
-         /* light blue pen for outline of background rectangle */
-         lb.lbColor = RGB(204,255,255);
-         hPenBackground = ExtCreatePen(PS_GEOMETRIC | PS_SOLID,
-                            (DWORD)1, &lb, 0, NULL); 
-         /* light blue brush for interior of background rectangle */
-         bgbrush = CreateSolidBrush(RGB(204,255,255));
-         /* GetClientRect returns the size of that part of the window
-            that is actually ours to draw in.
-          */
-         GetClientRect(hWnd, &lpRect);
-         windowwidth = lpRect.right;
-         windowheight = lpRect.bottom;
-         /* select background pen and brush */ 
-         SelectObject(hdc, hPenBackground);
-         SelectObject(hdc, bgbrush);
-         /* fill background */
-         Rectangle(hdc, 0, 0, windowwidth, windowheight);
-         /* select tree pen */
-         hPenOld = SelectObject(hdc, hPenTree); 
-         /* winplotpreviewcore calls makebox, plottree, plotlabels and
-            finishplotter
-          */
-         winplotpreviewcore(windowwidth, windowheight);
-         /* delete pens to recover memory */
-         DeleteObject(hPenTree); 
-         DeleteObject(hPenLabel);
-         DeleteObject(hPenBackground);
-         DeleteObject(bgbrush);
-         EndPaint( hWnd, &ps );
-         break;
-
-/**************************************************************\
-*     WM_COMMAND:                                              *
-\**************************************************************/
-
-      case WM_COMMAND:
-         switch( wParam ) {
-            case IDM_ABOUT:
-               DialogBox( ghInstance, "AboutDlg", hWnd, (DLGPROC)
-                          AboutDlgProc );
-            break;
-            case IDM_PLOT: // "Plot" menu item
-               winaction = plotnow;
-               DestroyWindow(hWnd);
-            break;
-            case IDM_CHANGE: // "Change Parameters" menu item
-               winaction = changeparms;
-               DestroyWindow(hWnd);
-            break;
-            case IDM_QUIT: // "Quit" menu item
-               winaction = quitnow;
-               DestroyWindow(hWnd);
-            break;
-         }
-      break;
-
-/**************************************************************\
-*     WM_DESTROY: PostQuitMessage() is called                  *
-\**************************************************************/
-
-      case WM_DESTROY:
-         PostQuitMessage( 0 );
-         break;
-
-/**************************************************************\
-*     Let the default window proc handle all other messages    *
-\**************************************************************/
-
-      default:
-         return( DefWindowProc( hWnd, msg, wParam, lParam ));
-   }
-
-   return 0;
-}
-
-/********************************************************************\
-* Function: LRESULT CALLBACK AboutDlgProc(HWND, UINT, WPARAM, LPARAM)*
-*                                                                    *
-*  Purpose: Processes "About" Dialog Box Messages                    *
-*                                                                    *
-* Comments: The About dialog box is displayed when the user clicks   *
-*           About from the Help menu.                                *
-*                                                                    *
-\********************************************************************/
-
-LRESULT CALLBACK AboutDlgProc( HWND hDlg, UINT uMsg, WPARAM wParam, LPARAM lParam )
-{
-   switch( uMsg ) {
-      case WM_INITDIALOG:
-         return TRUE;
-      case WM_COMMAND:
-         switch( wParam ) {
-            case IDOK:
-               EndDialog( hDlg, TRUE );
-               return TRUE;
-         }
-      break;
-   }
-
-   return FALSE;
-}
-
-
-#endif
