@@ -1,8 +1,3 @@
-
-#ifdef OSX_CARBON
-#include <Carbon/Carbon.h>
-#endif
-
 #include "phylip.h"
 #include "draw.h"
 
@@ -12,7 +7,7 @@
   Akiko Fuseki, Doug Buxton and Michal Palczewski. Permission is granted to 
   copy, distribute, and modify this program provided that (1) this copyright 
   message is not removed and (2) no fee is charged for this program. */ 
-
+/*
 #ifdef MAC
 char* about_message = 
   "Drawgram unrooted tree plotting program\r"
@@ -27,7 +22,8 @@ char* about_message =
   "(2) no fee is charged for this program.";
 #endif
 
-
+*/
+//#define JAVADEBUG
 
 #define gap 0.5    /* distance in character heights between the end
                       of a branch and the start of the name */
@@ -38,8 +34,7 @@ char *progname;
 
 long nextnode,  strpwide, strpdeep, strpdiv,
         strptop, strpbottom, payge, numlines, hpresolution, iteration;
-boolean preview, previewing, dotmatrix,
-         haslengths, uselengths, empty, rescaled, firstscreens,
+boolean dotmatrix, haslengths, uselengths, empty, rescaled, firstscreens,
          pictbold, pictitalic, pictshadow, pictoutline, multiplot, finished;
 double xmargin, ymargin, topoflabels, bottomoflabels, rightoflabels,
        leftoflabels, tipspacing,maxheight, scale, xscale, yscale,
@@ -51,7 +46,7 @@ double pagex, pagey, paperx, papery, hpmargin, vpmargin;
 
 double *textlength, *firstlet;
 striptype stripe;
-plottertype plotter, oldplotter, previewer;
+plottertype plotter, oldplotter;
 growth grows;
 treestyle style;
 node *root;
@@ -64,43 +59,12 @@ double trweight;   /* starting here, needed to make sccs version happy */
 boolean goteof;
 node *grbg;
 long *zeros;     /* ... down to here */
+boolean canbeplotted;
 
        enum {yes, no} penchange, oldpenchange;
 static enum {weighted, intermediate, centered, inner, vshaped} nodeposition;
 winactiontype winaction;
 
-#ifdef X
-String res[]= {
-        "*.input: True",
-        "*.menubar.orientation: horizontal",
-        "*.menubar.borderWidth: 0",
-        "*.drawing_area.background: #CCFFFF",
-        "*.drawing_area.foreground: #000000",
-        "*.menubar.right: ChainLeft",
-        "*.menubar.bottom: ChainTop",
-        "*.menubar.top: ChainTop",
-        "*.menubar.left: ChainLeft",
-        "*.drawing_area.fromVert: menubar",
-        "*.drawing_area.top: ChainTop",
-        "*.drawing_area.bottom: ChainBottom",
-        "*.drawing_area.left: ChainLeft",
-        "*.drawing_area.right: ChainRight",
-  "*.dialog.label: "
-  "Drawgram unrooted tree plotting program\\n"
-  "PHYLIP version 3.6 (c) Copyright 1986-2004\\n"
-  "by The University of Washington.\\n"  
-  "Written by Joseph Felsenstein and Christopher A. Meacham.\\n" 
-  "Additional code written by Hisashi Horino, Sean Lamont, Andrew Keefe,\\n"
-  "Daniel Fineman, Akiko Fuseki, Doug Buxton and Michal Palczewski.\\n"
-  "Permission is granted to copy, distribute and modify this program\\n"
-  "provided that\\n"
-  "(1) This copyright message is not removed and\\n"
-  "(2) no fee i charged for this program.",
-        NULL
-};
-#endif
-
-
 #ifndef OLDC
 /* function prototypes */
 void   initdrawgramnode(node **, node **, node *, long, long, long *, long *,
@@ -111,8 +75,13 @@ void   getparms(char);
 void   calctraverse(node *, double, double *);
 void   calculate(void);
 void   rescale(void);
-void   setup_environment(Char *argv[], boolean *);
-void   user_loop(boolean *);
+void   setup_environment(Char *argv[]);
+void   user_loop();
+void   drawgram(char* intreename, char* fontfilename, char* plotfilename, char* plotfileopt,
+                char* treegrows, char* stylekind, int usebranchlengths, double labelangle,
+                int scalebranchlength, double branchscale, double breadthdepthratio,
+                double stemltreedratio, double chhttipspratio, double xmarginratio, 
+                double ymarginratio, char* ancnodes, int  dofinalplot, char* finalplotkind);
 /* function prototypes */
 #endif
 
@@ -174,7 +143,6 @@ void initialparms()
 {
   /* initialize parameters */
   plotter = DEFPLOTTER;
-  previewer = DEFPREV;
   paperx=20.6375;
   pagex=20.6375;
   papery=26.9875;
@@ -196,7 +164,6 @@ void initialparms()
     nodeposition = centered;
   xmargin = 0.08 * xsize;
   ymargin = 0.08 * ysize;
-  preview = true;
   hpmargin = 0.02*pagex;
   vpmargin = 0.02*pagey;
 }  /* initialparms */
@@ -287,39 +254,12 @@ char showparms()
     case other:
       printf(" (Current output device unannounced)\n");
       break;
-    default:        /*case xpreview not handled */
+    default:        /*case not handled */
       break;
   }
-  printf(" V           Previewing device: ");
-  if (!preview)
-    printf(" (none)\n");
-  else {
-    switch (previewer) {
-      case ibm:
-        printf(" IBM PC graphics\n");
-        break;
-      case xpreview:
-        printf(" X Windows display\n");
-        break;
-      case tek:
-        printf(" Tektronix graphics screen\n");
-        break;
-      case mac:
-        printf(" Macintosh graphics screen\n");
-        break;
-      case decregis:
-        printf(" DEC ReGIS graphics (VT240 or DECTerm)\n");
-        break;
-      case winpreview:
-        printf(" MS Windows display\n");
-        break;
-      case other:
-        printf(" (Current previewing device unannounced)\n");
-        break;
-      default:   /* all other cases */
-        break;
-    }
-  }
+
+  printf(" (Preview no longer available)\n");
+
   printf(" H                  Tree grows:  ");
   printf((grows == vertical) ? "Vertically\n" : "Horizontally\n");
   printf(" S                  Tree style:  %s\n",
@@ -441,10 +381,6 @@ void getparms(char numtochange)
     getplotter();
     break;
 
-  case 'V':
-    getpreview();
-    break;
-
   case 'H':
     if (grows == vertical)
       grows = horizontal;
@@ -967,16 +903,19 @@ void calculate()
   leftfirst = firstlet[i];
   maxheight = 0.0;
   maxtextlength = 0.0;
+  //printf("fontname: %s\n",fontname);
   for (i = 0; i < nextnode; i++) {
    if (nodep[i]->tip) {
       textlength[i] = lengthtext(nodep[i]->nayme, nodep[i]->naymlength,
                                 fontname, font);
+      //printf("i: %li textlength[i]: %f nodep[i]->nayme: %s nodep[i]->naymlength: %li\n", i, textlength[i], nodep[i]->nayme, nodep[i]->naymlength);
       if (textlength[i]-0.5*firstlet[i] > maxtextlength) {
         maxtextlength = textlength[i]-0.5*firstlet[i];
         maxfirst = firstlet[i];
       }
     }
   }
+  //printf("maxtextlength: %f maxfirst: %f\n", maxtextlength, maxfirst);
   maxtextlength = maxtextlength + 0.5*maxfirst;
   fontheight = heighttext(font,fontname);
   if (style == circular) {
@@ -1138,6 +1077,7 @@ void calculate()
     rightoflabels *= labelheight;
   }
   if (style != circular) {
+    //printf("labelheight: %f angle: %f maxtextlength: %f maxfirst: %f\n", labelheight, angle, maxtextlength, maxfirst);
     topoflabels = labelheight *
               (1.0 + sin(angle) * (maxtextlength - 0.5 * maxfirst)
                    + cos(angle) * 0.5 * maxfirst);
@@ -1155,9 +1095,10 @@ void calculate()
 
 void rescale()
 {
-  /* compute coordinates of tree for plot or preview device */
+  /* compute coordinates of tree for plot device */
   long i;
   double treeheight, treewidth, extrax, extray, temp;
+   //printf("maxy: %f miny: %f maxx: %f minx: %f\n", maxy, miny, maxx, minx);
   treeheight = maxy - miny;
   treewidth = maxx - minx;
   if (style == circular) {
@@ -1176,6 +1117,7 @@ void rescale()
   }
   treewidth += rightoflabels + leftoflabels;
   treeheight += topoflabels + bottomoflabels;
+  //printf("rightoflabels: %f leftoflabels: %f topoflabels: %f bottomoflabels: %f treewidth: %f treeheight: %f\n", rightoflabels, leftoflabels, topoflabels, bottomoflabels, treewidth, treeheight);
   if (grows == vertical) {
     if (!rescaled)
       expand = bscale;
@@ -1197,7 +1139,10 @@ void rescale()
     extrax = (xsize - 2 * xmargin - treeheight * expand) / 2.0;
     extray = (ysize - 2 * ymargin - treewidth * expand) / 2.0;
   }
+  //printf("in rescale rescaled: %i treewidth: %f treeheight: %f expand: %f\n", rescaled, treewidth, treeheight, expand);
+  //printf("xsize: %f xmargin: %f ysize: %f ymargin: %f\n", xsize, xmargin, ysize, ymargin);
   for (i = 0; i < nextnode; i++) {
+     //printf("before rescale i: %li, nodep[i]: %f, %f\n", i, nodep[i]->xcoord, nodep[i]->ycoord);
     nodep[i]->xcoord = expand * (nodep[i]->xcoord + leftoflabels);
     nodep[i]->ycoord = expand * (nodep[i]->ycoord + bottomoflabels);
     if ((style != circular) && (grows == horizontal)) {
@@ -1207,6 +1152,7 @@ void rescale()
     }
     nodep[i]->xcoord += xmargin + extrax;
     nodep[i]->ycoord += ymargin + extray;
+     //printf("after rescale i: %li, nodep[i]: %f, %f\n", i, nodep[i]->xcoord, nodep[i]->ycoord);
   }
   if (style == circular) {
     xx0 = xmargin+extrax+expand*(leftoflabels + 0.5);
@@ -1226,6 +1172,8 @@ void plottree(node *p, node *q)
   double x00=0, y00=0, x1, y1, x2, y2, x3, y3, x4, y4,
            cc, ss, f, g, fract=0, minny, miny;
   node *pp;
+    //printf("p: %p q: %p xscale: %f xoffset: %f yscale: %f yoffset %f\n", p, q, xscale, xoffset, yscale, yoffset);
+   // fflush(stdout); 
 
   x2 = xscale * (xoffset + p->xcoord);
   y2 = yscale * (yoffset + p->ycoord);
@@ -1236,7 +1184,8 @@ void plottree(node *p, node *q)
   if (p != root) {
     x1 = xscale * (xoffset + q->xcoord);
     y1 = yscale * (yoffset + q->ycoord);
-
+    //printf("branch p: %f, %f q: %f, %f\n",p->xcoord, p->ycoord, q->xcoord, q->ycoord);
+    //fflush(stdout); 
     switch (style) {
 
     case cladogram:
@@ -1366,6 +1315,8 @@ void plottree(node *p, node *q)
         y1 =  yscale *  (yoffset + p->ycoord);
       }
     }
+    //printf("root p: %f, %f q: %f, %f\n",x2, y2, x1, y1);
+    //fflush(stdout); 
     plot(penup, x1, y1);
     plot(pendown, x2, y2);
   }
@@ -1413,8 +1364,8 @@ void plotlabels(char *fontname)
         if (right) {
           dx = labelheight * expand * cos(nodep[i]->oldtheta);
           dy = labelheight * expand * sin(nodep[i]->oldtheta);
-          dx -= labelheight * expand * 0.5 * vec * (cosl*sinv-sinl*cosv);
-          dy -= labelheight * expand * 0.5 * vec * (sinl*sinv+cosl*cosv);
+          dx += labelheight * expand * 0.5 * vec * (-cosl*sinv+sinl*cosv);
+          dy += labelheight * expand * 0.5 * vec * (-sinl*sinv-cosl*cosv);
         }
         if (left) {
           dx = labelheight * expand * cos(nodep[i]->oldtheta);
@@ -1422,13 +1373,13 @@ void plotlabels(char *fontname)
           dx -= labelheight * expand * textlength[i] * cosl;
           dy -= labelheight * expand * textlength[i] * sinl;
           dx += labelheight * expand * 0.5 * vec * (cosl*cosv+sinl*sinv);
-          dy -= labelheight * expand * 0.5 * vec * (-sinl*cosv+cosl*sinv);
+          dy += labelheight * expand * 0.5 * vec * (-sinl*cosv-cosl*sinv);
         }
       } else {
           dx = labelheight * expand * cos(nodep[i]->oldtheta);
           dy = labelheight * expand * sin(nodep[i]->oldtheta);
-          dx += labelheight * expand * 0.5 * vec * (cosl*cosv+sinl*sinv);
-          dy += labelheight * expand * 0.5 * vec * (-sinl*cosv+cosl*sinv);
+          dx -= labelheight * expand * 0.5 * firstlet[i] * (cosl-sinl*sinv);
+          dy -= labelheight * expand * 0.5 * firstlet[i] * (sinl+cosl*sinv);
         }
       if (style == circular) {
         plottext(lp->nayme, lp->naymlength,
@@ -1458,15 +1409,10 @@ void plotlabels(char *fontname)
 }  /* plotlabels */
 
 
-void setup_environment(Char *argv[], boolean *canbeplotted)
+void setup_environment(Char *argv[])
 {
   boolean firsttree;
   /* Set up all kinds of fun stuff */
-#ifdef MAC
-  OSErr retcode;
-  FInfo  fndrinfo;
-  macsetup("Drawgram","Preview");
-#endif
 #ifdef TURBOC
   if ((registerbgidriver(EGAVGA_driver) <0) ||
       (registerbgidriver(Herc_driver) <0)   ||
@@ -1487,96 +1433,711 @@ void setup_environment(Char *argv[], boolean *canbeplotted)
   root->oldlen = 0.0;
   printf("Tree has been read.\n");
   printf("Loading the font .... \n");
-  loadfont(font,argv[0]);
+  loadfont(font,FONTFILE,argv[0]);
   printf("Font loaded.\n");
-  previewing = false;
   ansi = ANSICRT;
   ibmpc = IBMCRT;
   firstscreens = true;
   initialparms();
-  (*canbeplotted) = false;
+  canbeplotted = false;
 }  /* setup_environment */
 
      
-void user_loop(boolean *canbeplotted)
+void user_loop()
 {
   char     input_char;
   long stripedepth;
   
-  while (!(*canbeplotted)) {
+  while (!canbeplotted) {
     do {
       input_char=showparms();
       firstscreens = false;
       if (input_char != 'Y')
         getparms(input_char);
     } while (input_char != 'Y');
+
+    
+ #ifdef JAVADEBUG    
+     // JRM Debug
+     
+    printf("\n***internal parameters***\n");
+    printf("fontname: %s\n", fontname);
+    printf("plotter: %i\n",plotter);
+    printf("paperx: %f\n",paperx);
+    printf("papery: %f\n",papery);
+    printf("hpmargin: %f\n",hpmargin);
+    printf("vpmargin: %f\n",vpmargin);
+    printf("pagex: %f\n",pagex);
+    printf("pagey: %f\n",pagey);
+    printf("xmargin: %f\n",xmargin);
+    printf("ymargin: %f\n",ymargin);
+    printf("firstscreens: %i\n",firstscreens);
+    printf("canbeplotted: %i\n",canbeplotted);
+    printf("style: %i\n",style);
+    printf("grows: %i\n",grows);
+    printf("labelrotation: %f\n",labelrotation);
+    printf("nodespace: %f\n",nodespace);
+    printf("stemlength: %f\n",stemlength);
+    printf("treedepth: %f\n",treedepth);
+    printf("bscale: %f\n",bscale);
+    printf("uselengths: %i\n",uselengths);
+    printf("nodeposition: %i\n",nodeposition);
+    printf("dotmatrix: %i\n",dotmatrix);
+    printf("xsize: %f\n", xsize);
+    printf("ysize: %f\n", ysize);
+    fflush(stdout);
+#endif
+    
     if (dotmatrix) {
       stripedepth = allocstripe(stripe,(strpwide/8),
                                 ((long)(yunitspercm * ysize)));
+      //printf("strpwide: %li, yunitspercm: %f, ysize: %f\n",strpwide, yunitspercm, ysize);
+      //printf("stripedepth: %li\n", stripedepth);
+      //fflush(stdout);
       strpdeep = stripedepth;
       strpdiv  = stripedepth;
     }
     plotrparms(spp); 
+    //printf("after plotrparms\n");
+    //printf("strpdeep: %li, yunitspercm: %f, ysize: %f\n",strpdeep, yunitspercm, ysize);
+    //fflush(stdout);
     numlines = dotmatrix ? 
       ((long)floor(yunitspercm * ysize + 0.5) / strpdeep) :1;
+    //printf("dotmatrix: %i numlines: %li\n",dotmatrix, numlines);
+    //fflush(stdout);
     xscale = xunitspercm;
     yscale = yunitspercm;
     calculate();
     rescale();
-    (*canbeplotted) = true;
-    if (preview) {
-      previewing = true;
-      printf("Preview window displayed... press \"Change\" button to return to menu.\n");
-      (*canbeplotted) = plotpreview(fontname,&xoffset,&yoffset,
-                                  &scale,spp,root);
-    } else 
-      (*canbeplotted)=true;
-    
-    if ((previewer == winpreview || previewer == xpreview || previewer == mac) 
-        && (winaction == quitnow)) {
-      break;
-    }
+    canbeplotted = true;
   }
 } /* user_loop */
 
 
-int main(int argc, Char *argv[])
-{
-  boolean canbeplotted;
-  boolean wasplotted = false;
-#ifdef MAC
-  OSErr retcode;
-  FInfo  fndrinfo;
-#ifdef OSX_CARBON
-  FSRef fileRef;
-  FSSpec fileSpec;
-#endif
-#ifdef __MWERKS__
-  SIOUXSetTitle("\pPHYLIP:  Drawtree");
-#endif
-  argv[0] = "Drawgram";
+void drawgram(
+  char   *intreename,
+  char   *fontfilename,
+  char   *plotfilename,
+  char   *plotfileopt,
+  char   *treegrows,
+  char   *stylekind,
+  int     usebranchlengths,
+  double  labelangle,
+  int     scalebranchlength,
+  double  branchscale,
+  double  breadthdepthratio,
+  double  stemltreedratio,
+  double  chhttipspratio,
+  double  xmarginratio,
+  double  ymarginratio,
+  char   *ancnodes,
+  int     dofinalplot,
+  char*   finalplotkind)
+
+{   
+    //printf("hello from DrawGram\n");
+    // setup before data is translated
+    char *previewfilename = "JavaPreview.ps";
+    
+    // from init
+    javarun   = true;
+    ansi = ANSICRT;
+    ibmpc = IBMCRT;
+    
+    firstscreens = false;
+    canbeplotted = true;
+    dotmatrix = false;
+
+    boolean wasplotted = false;
+    grbg = NULL;
+    progname = "Drawgram";
+    
+    initialparms();
+    
+    // translate Java doubles to Drawgram local variables
+    labelrotation = labelangle;
+    stemlength = stemltreedratio;
+    treedepth = breadthdepthratio;
+    bscale = branchscale;
+    nodespace = 1.0 / chhttipspratio;
+    xmargin = xmarginratio * paperx;
+    ymargin = ymarginratio * papery;
+    
+    // translate Java boolean to Phylip boolean
+    boolean doplot;
+    if (dofinalplot != 0)
+        doplot = true;
+    else
+        doplot = false;
+    
+    if (usebranchlengths != 0)
+        uselengths = true;
+    else
+        uselengths = false;
+    
+    if (scalebranchlength != 0)
+        rescaled = true;
+    else
+        rescaled = false;
+    
+    // plot style
+    style = phenogram;
+    if (!strcmp(stylekind,"cladogram"))
+        style = cladogram;
+    if (!strcmp(stylekind,"phenogram"))
+        style = phenogram;
+    if (!strcmp(stylekind,"curvogram"))
+        style = curvogram;
+    if (!strcmp(stylekind,"eurogram"))
+        style = eurogram;
+    if (!strcmp(stylekind,"swoopogram"))
+        style = swoopogram;
+    if (!strcmp(stylekind,"circular"))
+        style = circular;
+    
+    // tree growth direction
+    grows = horizontal;
+    if (!strcmp(treegrows,"vertical"))
+        grows = vertical;
+    
+    // node positions
+    if (!strcmp(ancnodes,"weighted"))
+        nodeposition = weighted;
+    if (!strcmp(ancnodes,"intermediate"))
+        nodeposition = intermediate;
+    if (!strcmp(ancnodes,"centered"))
+        nodeposition = centered;
+    if (!strcmp(ancnodes,"inner"))
+        nodeposition = inner;
+    if (!strcmp(ancnodes,"vshaped"))
+        nodeposition = vshaped;
+    
+    plotter = lw;
+    strcpy(afmfile,"none");
+    
+    if(dofinalplot)
+    {
+        if (!strcmp(finalplotkind,"lw"))
+        {
+            plotter = lw;
+        }        
+        /*
+        // not currently available
+        if(!strcmp(finalplotkind,"svg"))
+        {
+            plotter = svg;
+        }
+        */     
+        else if(!strcmp(finalplotkind,"hp"))
+        {
+            plotter = hp;
+        }       
+        if(!strcmp(finalplotkind,"tek"))
+        {
+            plotter = tek;
+        }       
+        if(!strcmp(finalplotkind,"ibm"))
+        {
+            plotter = ibm;
+        }       
+        if(!strcmp(finalplotkind,"mac"))
+        {
+            plotter = mac;
+        }      
+        if(!strcmp(finalplotkind,"houston"))
+        {
+            plotter = houston;
+        }     
+        if(!strcmp(finalplotkind,"decregis"))
+        {
+            plotter = decregis;
+        }     
+        if(!strcmp(finalplotkind,"epson"))
+        {
+            plotter = epson;
+        }     
+        if(!strcmp(finalplotkind,"oki"))
+        {
+            plotter = oki;
+        }       
+        if(!strcmp(finalplotkind,"fig"))
+        {
+            plotter = fig;
+        }      
+        if(!strcmp(finalplotkind,"citoh"))
+        {
+            plotter = citoh;
+        }
+        if(!strcmp(finalplotkind,"toshiba"))
+        {
+            plotter = toshiba;
+        }    
+        if(!strcmp(finalplotkind,"pcx"))
+        {
+            plotter = pcx;
+        }  
+        if(!strcmp(finalplotkind,"pcl"))
+        {
+            plotter = pcl;
+        }  
+        if(!strcmp(finalplotkind,"pict"))
+        {
+            plotter = pict;
+        }   
+        if(!strcmp(finalplotkind,"ray"))
+        {
+            plotter = ray;
+        }    
+        if(!strcmp(finalplotkind,"pov"))
+        {
+            plotter = pov;
+        }   
+        if(!strcmp(finalplotkind,"xbm"))
+        {
+            plotter = xbm;
+        }     
+        if(!strcmp(finalplotkind,"bmp"))
+        {
+            plotter = bmp;
+        }     
+        if(!strcmp(finalplotkind,"gif"))
+        {
+            plotter = gif;
+        }      
+        if(!strcmp(finalplotkind,"idraw"))
+        {
+            plotter = idraw;
+        }    
+        if(!strcmp(finalplotkind,"vrml"))
+        {
+            plotter = vrml;
+        }    
+        if(!strcmp(finalplotkind,"other"))
+        {
+            plotter = other;
+        }
+    }
+    else
+    {
+        // preview
+        plotter = lw;  // hardwired to ps
+    }
+    
+    // choose the best Hershey approximation of the font 
+    int fontid = figfontid(fontfilename);
+    //printf("fontfilename: %s id: %i ", fontfilename, fontid);
+    char* hersheyfontname = "font1";
+    switch (fontid)
+    {
+        case 4:  //AvantGarde-Book
+        case 8:  //Bookman-Light 
+        case 16: //Helvetica
+        case 20: //Helvetica-Narrow
+            hersheyfontname = "font1"; // romans sans
+        break;
+        
+        case 6:  //AvantGarde-Demi 
+        case 10: //Bookman-Demi
+        case 18: //Helvetica-Bold
+        case 22: //Helvetica-Narrow-Bold
+            hersheyfontname = "font2"; // romans sans bold
+        break;
+        
+        case 0: //Times-Roman
+        case 2: //Times-Bold
+        case 12: //Courier
+        case 14: //Courier-Bold
+        case 24: //NewCenturySchlbk-Roman
+        case 26: //NewCenturySchlbk-Bold
+        case 28: //Palatino-Roman
+        case 30: //Palatino-Bold
+            hersheyfontname = "font3"; // romans serif
+        break;
+        
+        case 1: //Times-Italic
+        case 5: //AvantGarde-BookOblique
+        case 9: //Bookman-LightItalic
+        case 13: //Courier-Italic
+        case 17: //Helvetica-Oblique
+        case 21: //Helvetica-Narrow-Oblique
+        case 25: //NewCenturySchlbk-Italic
+        case 29: //Palatino-Italic
+        case 33: //ZapfChancery-MediumItalic
+            hersheyfontname = "font4"; // romans serif italic
+        break;
+        
+        case 3: //Times-BoldItalic
+        case 7: //AvantGarde-DemiOblique
+        case 11: //Bookman-DemiItalic
+        case 15: //Courier-BoldItalic
+        case 19: //Helvetica-BoldOblique
+        case 23: //Helvetica-Narrow-BoldOblique
+        case 27: //NewCenturySchlbk-BoldItalic
+        case 31: //Palatino-BoldItalic
+            hersheyfontname = "font5"; // romans serif italic bold
+        break;
+        
+        default:
+        /*
+        case 32: //Symbol
+        case 34: //ZapfDingbats    
+        */
+            hersheyfontname = "font1"; // romans sans
+        break;
+            
+    }
+    //printf("hersheyfontname: %s\n", hersheyfontname);
+    loadfont(font,hersheyfontname,progname);
+ #ifdef JAVADEBUG    
+    // JRM Debug
+    // dump translated parameters from Java to make sure they made it
+    
+    printf("Starting parameters: \n");
+    printf("intreename: %s\n",intreename);
+    printf("fontfilename: %s\n",fontfilename);
+    printf("plotfilename: %s\n",plotfilename);
+    printf("plotfileopt: %s\n",plotfileopt);
+    printf("previewfilename: %s\n",previewfilename);
+    printf("rescaled: %i\n",rescaled);
+    printf("finalplotkind: %s\n",finalplotkind);
+    printf("doplot: %i\n",doplot);
+
+    fflush(stdout);
 #endif
 
+    // start drawgram code
+
+    /*
+    printf("hello from DrawGram\n");
+    printf("DRAWGRAM from PHYLIP version %s\n",VERSION);
+    fflush(stdout);
+    */
+  
+    // read tree
+    intree = fopen(intreename,"r"); 
+    boolean firsttree = true;
+    allocate_nodep(&nodep, &intree, &spp);
+    plotrparms(spp); 
+    treeread (intree, &root, treenode, &goteof, &firsttree, nodep, &nextnode, 
+      &haslengths, &grbg, initdrawgramnode,true,-1);
+    root->oldlen = 0.0;   
+    // if there are no lengths, shut uselengths off 
+    if (haslengths==0)
+        uselengths = false;     
+    //printf("Tree has been read.\n"); 
+    //printf("haslengths: %i\n",haslengths);
+    //fflush(stdout);  
+ 
+    // printer specific details to simulate interactive setup
+    // mostly from getplotter with some from plotrparms
+    // after treeread as some formats need some of the tree data
+    dotmatrix = false;
+    long stripedepth;
+    switch (plotter) {    
+        case lw:
+           strcpy(fontname, fontfilename);
+        break;
+    
+        case hp:
+            strcpy(fontname, "Hershey");
+        break;
+    
+        case tek:
+            strcpy(fontname, "Hershey");
+        break;
+    
+        case ibm:
+            strcpy(fontname, "Hershey");
+        break;
+    
+        case mac:
+            strcpy(fontname, "Hershey");
+        break;
+    
+        case houston:
+            strcpy(fontname, "Hershey");
+        break;
+    
+        case decregis:
+            strcpy(fontname, "Hershey");
+        break;
+    
+        case epson:
+            dotmatrix = true;
+            strcpy(fontname, "Hershey");
+            strpdiv = 1;
+            stripedepth = allocstripe(stripe,(strpwide/8),((long)(yunitspercm * ysize)));
+        break;
+    
+        case oki:
+            dotmatrix = true;
+            strcpy(fontname, "Hershey");
+            strpdiv = 1;
+            stripedepth = allocstripe(stripe,(strpwide/8),((long)(yunitspercm * ysize)));
+       break;
+    
+        case fig:
+             strcpy(fontname, fontfilename);
+        break;
+    
+        case citoh:
+            dotmatrix = true;
+            strcpy(fontname, "Hershey");
+            strpdiv = 1;
+            stripedepth = allocstripe(stripe,(strpwide/8),((long)(yunitspercm * ysize)));
+        break;
+    
+        case toshiba:
+            dotmatrix = true;
+            strcpy(fontname, "Hershey");
+            strpdiv = 4;
+            stripedepth = allocstripe(stripe,(strpwide/8),((long)(yunitspercm * ysize)));
+        break;
+    
+        case pcx:
+            dotmatrix = true;
+            strcpy(fontname, "Hershey");
+            // assume VGA 1024 x 768
+            strpwide = 1024;
+            yunitspercm = 768 / ysize;
+            resopts = 3;
+            strpdiv = 10;
+            stripedepth = allocstripe(stripe,(strpwide/8),((long)(yunitspercm * ysize)));
+        break;
+    
+        case pcl:
+            dotmatrix = true;
+            strcpy(fontname, "Hershey");
+            // assume 300 dpi
+            hpresolution = 300;
+            xunitspercm = 118.11023622;   /* 300 DPI = 118.1 DPC                    */
+            yunitspercm = 118.11023622;
+            strpwide = 2550;   /* 8.5 * 300 DPI                                     */
+            strpdeep = DEFAULT_STRIPE_HEIGHT;     /* height of the strip            */
+            strpdiv = DEFAULT_STRIPE_HEIGHT;      /* in this case == strpdeep       */
+            stripedepth = allocstripe(stripe,(strpwide/8),((long)(yunitspercm * ysize)));
+        break;
+    
+        case pict:
+            strcpy(fontname, fontfilename);
+        break;
+    
+        case ray:
+            strcpy(fontname, "Hershey");
+        break;
+    
+        case pov:
+            strcpy(fontname, "Hershey");
+        break;
+    
+        case xbm:
+            dotmatrix = true;
+            strcpy(fontname, "Hershey");
+            // assume 1000 x 1000
+            xunitspercm = 1.0;
+            yunitspercm = 1.0;
+            xsize = 1000;
+            ysize = 1000;
+            xmargin = 0.08 * xsize;
+            ymargin = 0.08 * ysize;
+            strpdeep = DEFAULT_STRIPE_HEIGHT;
+            strpdiv = DEFAULT_STRIPE_HEIGHT;
+            strpwide = (long)xsize;
+            stripedepth = allocstripe(stripe,(strpwide/8),((long)(yunitspercm * ysize)));
+       break;
+    
+        case bmp:
+            dotmatrix = true;
+            strcpy(fontname, "Hershey");
+            // assume 1000 x 1000
+            xunitspercm = 1.0;
+            yunitspercm = 1.0;
+            xsize = 1000;
+            ysize = 1000;
+            xmargin = 0.08 * xsize;
+            ymargin = 0.08 * ysize;
+            strpdeep = DEFAULT_STRIPE_HEIGHT;
+            strpdiv = DEFAULT_STRIPE_HEIGHT;
+            strpwide = (long)xsize;
+            stripedepth = allocstripe(stripe,(strpwide/8),((long)(yunitspercm * ysize)));
+           /*
+            printf("***bmp setup done\n");
+            printf("xsize: %f\n", xsize);
+            printf("ysize: %f\n", ysize);
+            printf("xmargin: %f\n",xmargin);
+            printf("ymargin: %f\n",ymargin);
+            printf("strpwide: %li, yunitspercm: %f, ysize: %f\n" ,strpwide, yunitspercm, ysize);
+            fflush(stdout);
+            */
+        break;
+    
+        case gif:
+            strcpy(fontname, fontfilename);
+        break;
+    
+        case idraw:
+            strcpy(fontname, "Times-Bold");
+        break;
+    
+        case vrml:
+            strcpy(fontname, "Hershey");
+            treecolor = 5;
+            namecolor = 4;
+            vrmlskycolornear = 6;
+            vrmlskycolorfar = 6;
+            vrmlgroundcolornear = 3;
+            vrmlgroundcolorfar = 3;
+        break;
+    
+        case other:
+            strcpy(fontname, "Hershey");
+        break;
+    
+        default:
+        break;
+    }
+    
+    numlines = dotmatrix ? ((long)floor(yunitspercm * ysize + 0.5) / strpdeep) :1;
+    xscale = xunitspercm;
+    yscale = yunitspercm;
+  
+ #ifdef JAVADEBUG    
+    // jrmdebug dump final parameter settings
+    printf("\n***internal parameters***\n");
+    printf("fontname: %s\n", fontname);
+    printf("plotter: %i\n",plotter);
+    printf("paperx: %f\n",paperx);
+    printf("papery: %f\n",papery);
+    printf("hpmargin: %f\n",hpmargin);
+    printf("vpmargin: %f\n",vpmargin);
+    printf("pagex: %f\n",pagex);
+    printf("pagey: %f\n",pagey);
+    printf("xmargin: %f\n",xmargin);
+    printf("ymargin: %f\n",ymargin);
+    printf("firstscreens: %i\n",firstscreens);
+    printf("canbeplotted: %i\n",canbeplotted);
+    printf("style: %i\n",style);
+    printf("grows: %i\n",grows);
+    printf("labelrotation: %f\n",labelrotation);
+    printf("nodespace: %f\n",nodespace);
+    printf("stemlength: %f\n",stemlength);
+    printf("treedepth: %f\n",treedepth);
+    printf("bscale: %f\n",bscale);
+    printf("uselengths: %i\n",uselengths);
+    printf("nodeposition: %i\n",nodeposition);
+    printf("dotmatrix: %i\n",dotmatrix);
+    printf("xsize: %f\n", xsize);
+    printf("ysize: %f\n", ysize);
+    printf("---internal vars---\n");
+    printf("nodespace: %f\n",nodespace);
+    printf("spp: %li\n",spp); 
+    printf("doplot: %i\n",doplot);
+    printf("dotmatrix: %i numlines: %li\n",dotmatrix, numlines);
+    fflush(stdout);
+#endif
+
+    calculate();
+    rescale();
+    
+    //printf("passed rescale\n");
+    //fflush(stdout);
+
+    int lenname;
+    if (doplot)
+    {
+        lenname = strlen(plotfilename);
+    }
+    else
+    {
+        lenname = strlen(previewfilename);
+    }
+    
+    char* usefilename = (char*) malloc(lenname + 1);
+    
+    if (doplot)
+    {
+        strcpy(usefilename, plotfilename);
+        strcpy(pltfilename, plotfilename);
+    }
+    else
+    {
+        strcpy(usefilename, previewfilename);
+    }
+    
+    strcpy(trefilename, intreename);
+
+    // Open plot files in binary mode.
+    plotfile = fopen(usefilename,plotfileopt);
+    //printf("initializing plotter\n");
+    //fflush(stdout);
+    initplotter(spp,fontname);
+    //printf("plotter initialized\n");
+    //printf("numlines: %li\n",numlines);
+    //fflush(stdout);
+    //printf("\nWriting plot file ...\n");
+    //fflush(stdout);
+
+    if (!dofinalplot)
+    {
+        /*
+        printf("calling makebox\n");
+        printf("fontname: %s\n",fontname);
+        printf("xoffset: %f\n",xoffset);
+        printf("yoffset: %f\n",yoffset);
+        printf("scale: %f\n",scale);
+        printf("spp: %li\n",spp);
+        fflush(stdout);
+        */
+        changepen(labelpen);
+        makebox(fontname,&xoffset,&yoffset,&scale,spp);
+        /*  
+        printf("back from makebox\n");
+        printf("fontname: %s\n",fontname);
+        printf("xoffset: %f\n",xoffset);
+        printf("yoffset: %f\n",yoffset);
+        printf("scale: %f\n",scale);
+        printf("spp: %li\n",spp);
+        fflush(stdout);
+        */
+        changepen(treepen);
+   }
+    drawit(fontname,&xoffset,&yoffset,numlines,root);
+    //printf("drawit done\n");
+    //fflush(stdout);
+    finishplotter();
+   //printf("finishplotter done\n");
+    //fflush(stdout);
+    fclose(plotfile);
+    
+    //printf("\nPlot written to file \"%s\"\n\n", pltfilename);
+    wasplotted = true;
+    fclose(intree);
+    //printf("Drawgram Done.\n\n");
+    return;
+}
+
+
+int main(int argc, Char *argv[])
+{
+  boolean wasplotted = false;
+  javarun = false;
+
+  argv[0] = "Drawgram";
   grbg = NULL;
   progname = argv[0];
 
-#ifdef X
-  nargc=argc;
-  nargv=argv;
-#endif
   
   init(argc, argv);
 
-  setup_environment(argv, &canbeplotted);
+  setup_environment(argv);
 
-  user_loop(&canbeplotted);
-  if (!((previewer == winpreview || previewer == xpreview || previewer == mac) 
-        && (winaction == quitnow))) {
+  user_loop();
+  if (!(winaction == quitnow)) {
     /* Open plot files in binary mode. */
     openfile(&plotfile,PLOTFILE,"plot file", "wb",argv[0],pltfilename);
-    previewing = false;
     initplotter(spp,fontname);
     numlines = dotmatrix ? ((long)floor(yunitspercm * ysize + 0.5)/strpdeep) : 1;
+    //printf("numlines: %li\n",numlines);
     if (plotter != ibm)
       printf("\nWriting plot file ...\n");
     drawit(fontname,&xoffset,&yoffset,numlines,root);
@@ -1586,36 +2147,7 @@ int main(int argc, Char *argv[])
     printf("\nPlot written to file \"%s\"\n\n", pltfilename);
   }
   FClose(intree);
-#ifdef MAC
-  if (plotter == pict && wasplotted){
-#ifdef OSX_CARBON
-    FSPathMakeRef((unsigned char *)pltfilename, &fileRef, NULL);
-    FSGetCatalogInfo(&fileRef, kFSCatInfoNone, NULL, NULL, &fileSpec, NULL);
-    FSpGetFInfo(&fileSpec, &fndrinfo);
-    fndrinfo.fdType='PICT';
-    fndrinfo.fdCreator='MDRW';
-    FSpSetFInfo(&fileSpec, &fndrinfo);
-#else
-    retcode=GetFInfo(CtoPstr(PLOTFILE),0,&fndrinfo);
-    fndrinfo.fdType='PICT';
-    fndrinfo.fdCreator='MDRW';
-    retcode=SetFInfo(CtoPstr(PLOTFILE),0,&fndrinfo);
-#endif
-  }
-  if (plotter == lw && wasplotted){
-#ifdef OSX_CARBON
-    FSPathMakeRef((unsigned char *)pltfilename, &fileRef, NULL);
-    FSGetCatalogInfo(&fileRef, kFSCatInfoNone, NULL, NULL, &fileSpec, NULL);
-    FSpGetFInfo(&fileSpec, &fndrinfo);
-    fndrinfo.fdType='TEXT';
-    FSpSetFInfo(&fileSpec, &fndrinfo);
-#else
-    retcode=GetFInfo(CtoPstr(PLOTFILE),0,&fndrinfo);
-    fndrinfo.fdType='TEXT';
-    retcode=SetFInfo(CtoPstr(PLOTFILE),0,&fndrinfo);
-#endif
-  }
-#endif
+
   printf("Done.\n\n");
 
 #ifdef WIN32
