@@ -1,10 +1,3 @@
-
-
-#ifdef OSX_CARBON
-#include <Carbon/Carbon.h>
-#endif
-
- 
 #include "phylip.h"
 #include "draw.h"
 
@@ -30,6 +23,7 @@ char* about_message =
   "(2) no fee is charged for this program.";
 #endif
 
+//#define JAVADEBUG
 
 #define GAP             0.5
 #define MAXITERATIONS   100
@@ -52,17 +46,19 @@ double      xmargin, ymargin, topoflabels, rightoflabels, leftoflabels,
              yscale, xoffset, yoffset, charht, xnow, ynow, xunitspercm,
              yunitspercm, xsize, ysize, xcorner, ycorner,labelheight,
              labelrotation, treeangle, expand, bscale, maxchange;
-boolean     canbeplotted, preview, previewing, dotmatrix,haslengths,
+boolean     canbeplotted, dotmatrix, haslengths,
              uselengths, regular, rotate, empty, rescaled,
              notfirst, improve, nbody, firstscreens, labelavoid;
 boolean     pictbold,pictitalic,pictshadow,pictoutline;
+boolean javarun;
 
 striptype stripe;
-plottertype plotter, oldplotter, previewer;
+plottertype plotter, oldplotter;
 growth grows;
 labelorient labeldirec;
 node *root, *where;
 pointarray nodep;
+pointarray treenode;
 fonttype font;
 enum {  yes, no } penchange, oldpenchange;
 char ch,resopts;
@@ -86,37 +82,6 @@ struct stackElem
 };
 typedef struct stackElem stackElemType;
 
-#ifdef X
-String res[]= {
-        "*.input: True",
-        "*.menubar.orientation: horizontal",
-        "*.menubar.borderWidth: 0",
-        "*.drawing_area.background: #CCFFFF",
-        "*.drawing_area.foreground: #000000",
-        "*.menubar.right: ChainLeft",
-        "*.menubar.bottom: ChainTop",
-        "*.menubar.top: ChainTop",
-        "*.menubar.left: ChainLeft",
-        "*.drawing_area.fromVert: menubar",
-        "*.drawing_area.top: ChainTop",
-        "*.drawing_area.bottom: ChainBottom",
-        "*.drawing_area.left: ChainLeft",
-        "*.drawing_area.right: ChainRight",
-        "*.dialog.label: "
-          "Drawtree unrooted tree plotting program\\n"
-  "PHYLIP version 3.6 (c) Copyright 1986-2004\\n"
-  "by The University of Washington.\\n"  
-  "Written by Joseph Felsenstein and Christopher A. Meacham.\\n" 
-  "Additional code written by Sean Lamont, Andrew Keefe, Hisashi Horino,\\n"
-  "Akiko Fuseki, Doug Buxton and Michal Palczewski.\\n"
-  "Permission is granted to copy, distribute and modify this program\\n"
-  "provided that\\n"
-  "(1) This copyright message is not removed and\\n"
-  "(2) no fee i charged for this program.",
-        NULL
-};
-#endif
-
 
 #ifndef OLDC
 /* function prototypes */
@@ -159,6 +124,12 @@ void   user_loop(void);
 void setup_environment(int argc, Char *argv[]);
 void polarize(node *p, double *xx, double *yy);
 double vCounterClkwiseU(double Xu, double Yu, double Xv, double Yv);
+void drawtree(char* intreename, char* plotfilename, char* plotfileopt, char* fontfilename,
+              char* treegrows, int usebranchlengths, char* labeldirecstr, double labelangle,
+              double treerotation, double treearc, char* iterationkind, int iterationcount,
+              int regularizeangles, int avoidlabeloverlap, int branchrescale,
+              double branchscaler, double relcharhgt, double xmarginratio, 
+              double ymarginratio, int dofinalplot, char* finalplotkind);
 /* function prototypes */
 #endif
 
@@ -238,9 +209,7 @@ void initialparms()
   ymargin = 0.08 * ysize;
   labelrotation = 0.0;
   charht = 0.3333;
-  preview = true;  
   plotter = DEFPLOTTER;
-  previewer = DEFPREV;
   hpmargin = 0.02*pagex;
   vpmargin = 0.02*pagey;
   labelavoid = false;
@@ -342,55 +311,12 @@ char showparms()
   case gif:
   case other:
     break ;
-  default:        /* case xpreview not handled        */
+  default:        /* case not handled        */
     break;
   }
-  printf(" V           Previewing device: ");
-  if (!preview)
-    printf(" (none)\n");
-  else {
-    switch (previewer) {
-      case ibm:
-        printf(" IBM PC graphics (CGA, EGA, or VGA)\n");
-        break;
-      case xpreview:
-        printf(" X Windows display\n");
-        break;
-      case tek:
-        printf(" Tektronix graphics screen\n");
-        break;
-      case mac:
-        printf(" Macintosh graphics screen\n");
-        break;
-      case decregis:
-        printf(" DEC ReGIS graphics (VT240 or DECTerm)\n");
-        break;
-      case winpreview:
-        printf(" MS Windows display\n");
-        break;
-    case lw:
-    case hp:
-    case houston:
-    case epson:
-    case oki:
-    case fig:
-    case citoh:
-    case toshiba:
-    case pcx:
-    case pcl:
-    case pict:
-    case ray:
-    case pov:
-    case bmp:
-    case xbm:
-    case gif:
-    case idraw:
-    case other:
-      break ;
-    default:        /* case vrml not handled        */
-      break;
-    }
-  }
+
+  printf(" (Preview not available)\n");
+
   printf(" B          Use branch lengths:  ");
   if (haslengths)
     printf("%s\n",uselengths ? "Yes" : "No");
@@ -557,10 +483,6 @@ void getparms(char numtochange)
     getplotter();
     break;
 
-  case 'V':
-    getpreview();
-    break;
-
   case '#':
     loopcount2 = 0;
     for (;;){
@@ -879,7 +801,6 @@ void getwidth(node *p)
   /* get width and depth beyond each node */
   double nw, nd;
   node *pp, *qq;
-
   nd = 0.0;
   if (p->tip)
     nw = 1.0;
@@ -2126,6 +2047,7 @@ void calculate()
     for (i = 0; i < nextnode; i++)
       nodep[i]->length = fabs(nodep[i]->oldlen);
   }
+
   getwidth(root);
   nttot = root->width;
   for (i = 0; i < nextnode; i++)
@@ -2143,6 +2065,7 @@ void calculate()
     labangle = pi * labelrotation / 180.0;
   textlength = (double*) Malloc(nextnode*sizeof(double));
   firstlet = (double*) Malloc(nextnode*sizeof(double));
+
   for (i = 0; i < nextnode; i++) {
     if (nodep[i]->tip) {
       textlength[i] = lengthtext(nodep[i]->nayme, nodep[i]->naymlength,
@@ -2239,7 +2162,7 @@ void calculate()
 
 void rescale()
 {
-  /* compute coordinates of tree for plot or preview device */
+  /* compute coordinates of tree for plot device */
   long i;
   double treeheight, treewidth, extrax, extray, temp;
 
@@ -2389,7 +2312,7 @@ void plotlabels(char *fontname)
 
 void user_loop()
 {
-  /* loop to make preview window and decide what to do with it */
+  /* loop to decide what to do */
 
   long loopcount;
   char input_char;
@@ -2411,14 +2334,6 @@ void user_loop()
     calculate();
     rescale();
     canbeplotted = true;
-    if (preview) {
-      printf("Preview window displayed... press \"Change\" button to return to menu.\n");
-      canbeplotted=plotpreview(fontname,&xoffset,&yoffset,&scale,spp,root);
-    } else {
-      canbeplotted = true;
-    }
-    if ((previewer == winpreview || previewer == xpreview || previewer == mac) && (winaction == quitnow))
-      canbeplotted = true;
  }
 } /* user_loop */
 
@@ -2431,13 +2346,7 @@ void setup_environment(int argc, Char *argv[])
   char *pChar;
   double i;
   boolean firsttree;
-  pointarray treenode = NULL;
-#ifdef MAC
-  OSErr retcode;
-  FInfo  fndrinfo;
-  macsetup("Drawtree","Preview");
-#endif
-
+  treenode = NULL;
   
 #ifdef TURBOC
   if ((registerbgidriver(EGAVGA_driver) <0) ||
@@ -2470,9 +2379,8 @@ void setup_environment(int argc, Char *argv[])
   rotate = true;
   printf("Tree has been read.\n");
   printf("Loading the font ... \n");
-  loadfont(font,argv[0]);
+  loadfont(font,FONTFILE,argv[0]);
   printf("Font loaded.\n");
-  previewing = false;
   ansi = ANSICRT;
   ibmpc = IBMCRT;
   firstscreens = true;
@@ -2505,11 +2413,606 @@ void setup_environment(int argc, Char *argv[])
   return;
 }  /* setup_environment */
 
+void drawtree(
+    char*  intreename,
+    char*  plotfilename,
+    char*  plotfileopt,
+    char*  fontfilename,
+    char*  treegrows,
+    int    usebranchlengths,
+    char*  labeldirecstr,
+    double labelangle,
+    double treerotation,
+    double treearc,
+    char*  iterationkind,
+    int    iterationcount,
+    int    regularizeangles,
+    int    avoidlabeloverlap,
+    int    branchrescale,
+    double branchscaler,
+    double relcharhgt,
+    double  xmarginratio,
+    double  ymarginratio,
+    int    dofinalplot,
+    char*  finalplotkind)
+{
+    //printf("hello from DrawTree\n");    //JRMDebug
+    //fflush(stdout);
+
+    char *previewfilename = "JavaPreview.ps";
+    
+    // from init
+    javarun   = true;
+    ansi = ANSICRT;
+    ibmpc = IBMCRT;
+    
+    firstscreens = false;
+    canbeplotted = true;
+    dotmatrix = false;
+
+    boolean wasplotted = false;
+    grbg = NULL;
+    progname = "Drawtree";
+    
+    initialparms();
+    
+    // translate Java doubles and ints to Drawtree local variables
+    labelrotation = labelangle;
+    treeangle     = treerotation * pi / 180;
+    ark           = treearc * pi / 180;
+    bscale        = branchscaler;
+    charht        = relcharhgt;
+    maxNumOfIter  = iterationcount;
+    xmargin = xmarginratio * paperx;
+    ymargin = ymarginratio * papery;
+      
+    // translate Java boolean to Phylip boolean
+    boolean doplot;
+    if (dofinalplot != 0)
+        doplot = true;
+    else
+        doplot = false;
+    
+    if (usebranchlengths != 0)
+        uselengths = true;
+    else
+        uselengths = false;
+    
+    if (regularizeangles != 0)
+        regular = true;
+    else
+        regular = false;
+    
+    if (avoidlabeloverlap != 0)
+        labelavoid = true;
+    else
+        labelavoid = false;
+    
+    if (branchrescale != 0)
+        rescaled = true;
+    else
+        rescaled = false;
+
+    // label direction
+    labeldirec = middle;
+    if (!strcmp(labeldirecstr,"fixed"))
+        labeldirec = fixed;
+    if (!strcmp(labeldirecstr,"middle"))
+        labeldirec = middle;
+    if (!strcmp(labeldirecstr,"radial"))
+        labeldirec = radial;
+    if (!strcmp(labeldirecstr,"along"))
+        labeldirec = along;
+    
+    // iterate to improve tree
+    improve = false;
+    nbody = false;
+    if (!strcmp(iterationkind,"improve"))
+    {
+        improve = true;
+    }
+    if (!strcmp(iterationkind,"nbody"))
+    {
+        improve = true;
+        nbody = true;
+    }
+
+  // tree growth direction
+    grows = horizontal;
+    if (!strcmp(treegrows,"vertical"))
+        grows = vertical;
+
+  // figure out plot type
+    plotter = lw;
+    strcpy(afmfile,"none");
+    
+    if(dofinalplot)
+    {
+        if (!strcmp(finalplotkind,"lw"))
+        {
+            plotter = lw;
+        }
+        
+        /*
+        // not currently available
+        if(!strcmp(finalplotkind,"svg"))
+        {
+            plotter = svg;
+        }
+        */
+        
+        else if(!strcmp(finalplotkind,"hp"))
+        {
+            plotter = hp;
+        }
+        
+        if(!strcmp(finalplotkind,"tek"))
+        {
+            plotter = tek;
+        }
+        
+        if(!strcmp(finalplotkind,"ibm"))
+        {
+            plotter = ibm;
+        }
+        
+        if(!strcmp(finalplotkind,"mac"))
+        {
+            plotter = mac;
+        }
+        
+        if(!strcmp(finalplotkind,"houston"))
+        {
+            plotter = houston;
+        }
+        
+        if(!strcmp(finalplotkind,"decregis"))
+        {
+            plotter = decregis;
+        }
+        
+        if(!strcmp(finalplotkind,"epson"))
+        {
+            plotter = epson;
+        }
+        
+        if(!strcmp(finalplotkind,"oki"))
+        {
+            plotter = oki;
+        }
+        
+        if(!strcmp(finalplotkind,"fig"))
+        {
+            plotter = fig;
+        }
+        
+        if(!strcmp(finalplotkind,"citoh"))
+        {
+            plotter = citoh;
+        }
+        
+        if(!strcmp(finalplotkind,"toshiba"))
+        {
+            plotter = toshiba;
+        }
+        
+        if(!strcmp(finalplotkind,"pcx"))
+        {
+            plotter = pcx;
+        }
+        
+        if(!strcmp(finalplotkind,"pcl"))
+        {
+            plotter = pcl;
+        }
+        
+        if(!strcmp(finalplotkind,"pict"))
+        {
+            plotter = pict;
+        }
+        
+        if(!strcmp(finalplotkind,"ray"))
+        {
+            plotter = ray;
+        }
+        
+        if(!strcmp(finalplotkind,"pov"))
+        {
+            plotter = pov;
+        }
+        
+        if(!strcmp(finalplotkind,"xbm"))
+        {
+            plotter = xbm;
+        }
+        
+        if(!strcmp(finalplotkind,"bmp"))
+        {
+            plotter = bmp;
+        }
+        
+        if(!strcmp(finalplotkind,"gif"))
+        {
+            plotter = gif;
+        }
+        
+        if(!strcmp(finalplotkind,"idraw"))
+        {
+            plotter = idraw;
+        }
+        
+        if(!strcmp(finalplotkind,"vrml"))
+        {
+            plotter = vrml;
+        }
+        
+        if(!strcmp(finalplotkind,"other"))
+        {
+            plotter = other;
+        }
+    }
+    else
+    {
+        // preview
+        plotter = lw;  // hardwired to ps
+    }
+    
+    // choose the best Hershey approximation of the font 
+    int fontid = figfontid(fontfilename);
+    //printf("fontfilename: %s id: %i ", fontfilename, fontid);
+    char* hersheyfontname = "font1";
+    switch (fontid)
+    {
+        case 4:  //AvantGarde-Book
+        case 8:  //Bookman-Light 
+        case 16: //Helvetica
+        case 20: //Helvetica-Narrow
+            hersheyfontname = "font1"; // romans sans
+        break;
+        
+        case 6:  //AvantGarde-Demi 
+        case 10: //Bookman-Demi
+        case 18: //Helvetica-Bold
+        case 22: //Helvetica-Narrow-Bold
+            hersheyfontname = "font2"; // romans sans bold
+        break;
+        
+        case 0: //Times-Roman
+        case 2: //Times-Bold
+        case 12: //Courier
+        case 14: //Courier-Bold
+        case 24: //NewCenturySchlbk-Roman
+        case 26: //NewCenturySchlbk-Bold
+        case 28: //Palatino-Roman
+        case 30: //Palatino-Bold
+            hersheyfontname = "font3"; // romans serif
+        break;
+        
+        case 1: //Times-Italic
+        case 5: //AvantGarde-BookOblique
+        case 9: //Bookman-LightItalic
+        case 13: //Courier-Italic
+        case 17: //Helvetica-Oblique
+        case 21: //Helvetica-Narrow-Oblique
+        case 25: //NewCenturySchlbk-Italic
+        case 29: //Palatino-Italic
+        case 33: //ZapfChancery-MediumItalic
+            hersheyfontname = "font4"; // romans serif italic
+        break;
+        
+        case 3: //Times-BoldItalic
+        case 7: //AvantGarde-DemiOblique
+        case 11: //Bookman-DemiItalic
+        case 15: //Courier-BoldItalic
+        case 19: //Helvetica-BoldOblique
+        case 23: //Helvetica-Narrow-BoldOblique
+        case 27: //NewCenturySchlbk-BoldItalic
+        case 31: //Palatino-BoldItalic
+            hersheyfontname = "font5"; // romans serif italic bold
+        break;
+        
+        default:
+        /*
+        case 32: //Symbol
+        case 34: //ZapfDingbats    
+        */
+            hersheyfontname = "font1"; // romans sans
+        break;
+            
+    }
+    //printf("hersheyfontname: %s\n", hersheyfontname);
+    loadfont(font,hersheyfontname,progname);
+    
+    
+ #ifdef JAVADEBUG    
+    // dump translated parameters from Java to make sure they made it
+    //JRMDebug
+    printf("***Java input parameters***\n");
+    printf("intreename: %s\n",intreename);
+    printf("plotfilename: %s\n",plotfilename);
+    printf("plotfileopt: %s\n",plotfileopt);
+    printf("fontfilename: %s\n",fontfilename);
+    printf("usebranchlengths:: %i\n",usebranchlengths);
+    printf("labeldirecstr: %s\n",labeldirecstr);
+    printf("labelangle: %f\n",labelangle);
+    printf("treerotation: %f\n",treerotation);
+    printf("treearc: %f\n",treearc);
+    printf("iterationkind: %s\n",iterationkind);
+    printf("iterationcount: %i\n",iterationcount);
+    printf("regularizeangles: %i\n",regularizeangles);
+    printf("avoidlabeloverlap: %i\n",avoidlabeloverlap);
+    printf("branchrescale: %i\n",branchrescale);
+    printf("branchscaler: %f\n",branchscaler);
+    printf("relcharhgt: %f\n",relcharhgt);
+    printf("dofinalplot: %i\n",dofinalplot);
+    printf("previewfilename: %s\n",previewfilename);
+    printf("finalplotkind: %s\n",finalplotkind);
+    printf("doplot: %i\n",doplot);
+    fflush(stdout);    
+#endif   
+    
+    // read tree
+    intree = fopen(intreename,"r"); 
+    boolean firsttree = true;
+    allocate_nodep(&nodep, &intree, &spp);
+    plotrparms(spp); 
+    treeread (intree, &root, treenode, &goteof, &firsttree, nodep, &nextnode, 
+      &haslengths, &grbg, initdrawtreenode,true,-1);
+    root->oldlen = 0.0;   //???
+    // if there are no lengths, shut uselengths off 
+    if (haslengths==0)
+    {
+        uselengths = false;
+    }
+    //printf("Tree has been read.\n"); 
+    //printf("haslengths: %i\n",haslengths);
+    //fflush(stdout);  
+  
+    // printer specific details to simulate interactive setup
+    // mostly from getplotter with some from plotrparms
+    // after treeread as some formats need some of the tree data
+    dotmatrix = false;
+    long stripedepth;
+    switch (plotter) {    
+        case lw:
+           strcpy(fontname, fontfilename);
+        break; 
+        case hp:
+            strcpy(fontname, "Hershey");
+        break;  
+        case tek:
+            strcpy(fontname, "Hershey");
+        break;  
+        case ibm:
+            strcpy(fontname, "Hershey");
+        break;  
+        case mac:
+            strcpy(fontname, "Hershey");
+        break;  
+        case houston:
+            strcpy(fontname, "Hershey");
+        break; 
+        case decregis:
+            strcpy(fontname, "Hershey");
+        break; 
+        case epson:
+            dotmatrix = true;
+            strcpy(fontname, "Hershey");
+            strpdiv = 1;
+            stripedepth = allocstripe(stripe,(strpwide/8),((long)(yunitspercm * ysize)));
+        break;
+        case oki:
+            dotmatrix = true;
+            strcpy(fontname, "Hershey");
+            strpdiv = 1;
+            stripedepth = allocstripe(stripe,(strpwide/8),((long)(yunitspercm * ysize)));
+        break;
+        case fig:
+             strcpy(fontname, fontfilename);
+        break;
+        case citoh:
+            dotmatrix = true;
+            strcpy(fontname, "Hershey");
+            strpdiv = 1;
+            stripedepth = allocstripe(stripe,(strpwide/8),((long)(yunitspercm * ysize)));
+        break;
+        case toshiba:
+            dotmatrix = true;
+            strcpy(fontname, "Hershey");
+            strpdiv = 4;
+            stripedepth = allocstripe(stripe,(strpwide/8),((long)(yunitspercm * ysize)));
+        break;
+        case pcx:
+            dotmatrix = true;
+            strcpy(fontname, "Hershey");
+            // assume VGA 1024 x 768
+            strpwide = 1024;
+            yunitspercm = 768 / ysize;
+            resopts = 3;
+            strpdiv = 10;
+            stripedepth = allocstripe(stripe,(strpwide/8),((long)(yunitspercm * ysize)));
+        break; 
+        case pcl:
+            dotmatrix = true;
+            strcpy(fontname, "Hershey");
+            // assume 300 dpi
+            hpresolution = 300;
+            xunitspercm = 118.11023622;   /* 300 DPI = 118.1 DPC                    */
+            yunitspercm = 118.11023622;
+            strpwide = 2550;   /* 8.5 * 300 DPI                                     */
+            strpdeep = DEFAULT_STRIPE_HEIGHT;     /* height of the strip            */
+            strpdiv = DEFAULT_STRIPE_HEIGHT;      /* in this case == strpdeep       */
+            stripedepth = allocstripe(stripe,(strpwide/8),((long)(yunitspercm * ysize)));
+        break;  
+        case pict:
+            strcpy(fontname, fontfilename);
+        break; 
+        case ray:
+            strcpy(fontname, "Hershey");
+        break;
+        case pov:
+            strcpy(fontname, "Hershey");
+        break;
+        case xbm:
+            dotmatrix = true;
+            strcpy(fontname, "Hershey");
+            // assume 1000 x 1000
+            xunitspercm = 1.0;
+            yunitspercm = 1.0;
+            xsize = 1000;
+            ysize = 1000;
+            xmargin = 0.08 * xsize;
+            ymargin = 0.08 * ysize;
+            strpdeep = DEFAULT_STRIPE_HEIGHT;
+            strpdiv = DEFAULT_STRIPE_HEIGHT;
+            strpwide = (long)xsize;
+            stripedepth = allocstripe(stripe,(strpwide/8),((long)(yunitspercm * ysize)));
+        break;
+        case bmp:
+            dotmatrix = true;
+            strcpy(fontname, "Hershey");
+            // assume 1000 x 1000
+            xunitspercm = 1.0;
+            yunitspercm = 1.0;
+            xsize = 1000;
+            ysize = 1000;
+            xmargin = 0.08 * xsize;
+            ymargin = 0.08 * ysize;
+            strpdeep = DEFAULT_STRIPE_HEIGHT;
+            strpdiv = DEFAULT_STRIPE_HEIGHT;
+            strpwide = (long)xsize;
+            stripedepth = allocstripe(stripe,(strpwide/8),((long)(yunitspercm * ysize)));
+           /*
+            printf("***bmp setup done\n");
+            printf("xsize: %f\n", xsize);
+            printf("ysize: %f\n", ysize);
+            printf("xmargin: %f\n",xmargin);
+            printf("ymargin: %f\n",ymargin);
+            printf("strpwide: %li, yunitspercm: %f, ysize: %f\n" ,strpwide, yunitspercm, ysize);
+            fflush(stdout);
+            */
+        break;
+        case gif:
+            strcpy(fontname, fontfilename);
+        break;
+        case idraw:
+            strcpy(fontname, "Times-Bold");
+        break; 
+        case vrml:
+            strcpy(fontname, "Hershey");
+            treecolor = 5;
+            namecolor = 4;
+            vrmlskycolornear = 6;
+            vrmlskycolorfar = 6;
+            vrmlgroundcolornear = 3;
+            vrmlgroundcolorfar = 3;
+        break;
+        case other:
+            strcpy(fontname, "Hershey");
+        break;
+    
+        default:
+        break;
+    }
+    
+    numlines = dotmatrix ? ((long)floor(yunitspercm * ysize + 0.5) / strpdeep) :1;
+    xscale = xunitspercm;
+    yscale = yunitspercm;
+    
+#ifdef JAVADEBUG    
+    printf("\n***internal parameters***\n");
+    printf("fontname: %s\n", fontname);
+    printf("plotter: %i\n",plotter);
+    printf("paperx: %f\n",paperx);
+    printf("papery: %f\n",papery);
+    printf("hpmargin: %f\n",hpmargin);
+    printf("vpmargin: %f\n",vpmargin);
+    printf("pagex: %f\n",pagex);
+    printf("pagey: %f\n",pagey);
+    printf("xmargin: %f\n",xmargin);
+    printf("ymargin: %f\n",ymargin);
+    printf("rescaled: %i\n",rescaled);
+    printf("firstscreens: %i\n",firstscreens);
+    printf("canbeplotted: %i\n",canbeplotted);
+    printf("labelrotation: %f\n",labelrotation);
+    printf("treeangle: %f\n",treeangle);
+    printf("maxNumOfIter: %li\n",maxNumOfIter);
+    printf("ark: %f\n",ark);
+    printf("bscale: %f\n",bscale);
+    printf("charht: %f\n",charht);
+    printf("uselengths: %i\n",uselengths);
+    printf("regular: %i\n",regular);
+    printf("rescaled: %i\n",rescaled);
+    printf("labeldirec: %i\n",labeldirec);
+    printf("improve: %i\n",improve);
+    printf("nbody: %i\n",nbody);
+    printf("grows: %i\n",grows);
+    printf("dotmatrix: %i numlines: %li\n",dotmatrix, numlines);
+    fflush(stdout);
+#endif   
+    
+    // set up node link structure
+    node *q, *r;
+    q = root;
+    r = root;
+    while (!(q->next == root))
+    q = q->next;
+    q->next = root->next;
+    root = q;
+    chuck(&grbg, r);
+    nodep[spp] = q;
+    where = root;
+    rotate = true;
+    
+    calculate();
+    rescale();
+    
+    int lenname;
+    if (doplot)
+    {
+        lenname = strlen(plotfilename);
+    }
+    else
+    {
+        lenname = strlen(previewfilename);
+    }
+    
+    char* usefilename = (char*) malloc(lenname + 1);
+    if (doplot)
+    {
+        strcpy(usefilename, plotfilename);
+    }
+    else
+    {
+        strcpy(usefilename, previewfilename);
+    }
+    
+    // Open plot files in binary mode.
+    plotfile = fopen(usefilename,plotfileopt);  
+    initplotter(spp,fontname);
+    numlines = dotmatrix ? ((long)floor(yunitspercm * ysize + 0.5)/strpdeep) : 1;
+    
+    if (!dofinalplot)
+    {
+        changepen(labelpen);
+        makebox(fontname,&xoffset,&yoffset,&scale,spp);
+        changepen(treepen);
+    }
+    drawit(fontname,&xoffset,&yoffset,numlines,root);
+    finishplotter();
+    fclose(plotfile);
+    wasplotted = true;    
+    fclose(intree);
+    return;
+}
+
+
 
 int main(int argc, Char *argv[])
 {
   long stripedepth;
   boolean wasplotted = false;
+  javarun = false;
 #ifdef MAC
   char filename1[FNMLNGTH];
   OSErr retcode;
@@ -2522,10 +3025,6 @@ int main(int argc, Char *argv[])
   SIOUXSetTitle("\pPHYLIP:  Drawtree");
 #endif
   argv[0] = "Drawtree";
-#endif
-#ifdef X
-  nargc=argc;
-  nargv=argv;
 #endif
   init(argc,argv);
   
@@ -2536,7 +3035,40 @@ int main(int argc, Char *argv[])
 
 
   user_loop();
-  
+    
+ #ifdef JAVADEBUG    
+    //JRMDebug
+    printf("\n***internal parameters***\n");
+    printf("fontname: %s\n", fontname);
+    printf("plotter: %i\n",plotter);
+    printf("paperx: %f\n",paperx);
+    printf("papery: %f\n",papery);
+    printf("hpmargin: %f\n",hpmargin);
+    printf("vpmargin: %f\n",vpmargin);
+    printf("pagex: %f\n",pagex);
+    printf("pagey: %f\n",pagey);
+    printf("xmargin: %f\n",xmargin);
+    printf("ymargin: %f\n",ymargin);
+    printf("rescaled: %i\n",rescaled);
+    printf("firstscreens: %i\n",firstscreens);
+    printf("canbeplotted: %i\n",canbeplotted);
+    printf("labelrotation: %f\n",labelrotation);
+    printf("treeangle: %f\n",treeangle);
+    printf("maxNumOfIter: %li\n",maxNumOfIter);
+    printf("ark: %f\n",ark);
+    printf("bscale: %f\n",bscale);
+    printf("charht: %f\n",charht);
+    printf("uselengths: %i\n",uselengths);
+    printf("regular: %i\n",regular);
+    printf("rescaled: %i\n",rescaled);
+    printf("labeldirec: %i\n",labeldirec);
+    printf("improve: %i\n",improve);
+    printf("nbody: %i\n",nbody);
+    printf("grows: %i\n",grows);
+    printf("dotmatrix: %i\n",dotmatrix);
+    fflush(stdout);
+#endif
+    
   if (dotmatrix) {
     stripedepth = allocstripe(stripe,(strpwide/8),
                               ((long)(yunitspercm * ysize)));
@@ -2544,11 +3076,9 @@ int main(int argc, Char *argv[])
     strpdiv  = stripedepth;
   }
 
-  if (!((previewer == winpreview || previewer == xpreview || previewer == mac)
-        && (winaction == quitnow))) {
-    /* Open plotfiles in binary mode */
+  if (!(winaction == quitnow)) {
+    // Open plotfiles in binary mode 
     openfile(&plotfile, PLOTFILE, "plot file", "wb", argv[0], pltfilename);
-    previewing = false;
     initplotter(spp,fontname);
     numlines = dotmatrix ? ((long)floor(yunitspercm * ysize + 0.5)/strpdeep) : 1;   
     if (plotter != ibm)
