@@ -1120,10 +1120,9 @@ void maketree()
     }
   }
   if (jumb == njumble && progress) {
-    printf("\nOutput written to file \"%s\"\n\n", outfilename);
+    printf("\nOutput written to file \"%s\"\n", outfilename);
     if (trout) {
-      printf("Tree also written onto file \"%s\"\n", outtreename);
-      putchar('\n');
+      printf("\nTree also written onto file \"%s\"\n", outtreename);
     }
   }
 }  /* maketree */
@@ -1172,7 +1171,7 @@ int main(int argc, Char *argv[])
   fixmacfile(outfilename);
   fixmacfile(outtreename);
 #endif
-  printf("Done.\n\n");
+  printf("\nDone.\n\n");
 #ifdef WIN32
   phyRestoreConsoleAttributes();
 #endif
