@@ -223,8 +223,9 @@ void doinit()
   nonodes2 += (njoin ? 0 : 1);
   getoptions();
   alloctree(&curtree.nodep, nonodes2+1);
-  p = curtree.nodep[nonodes2]->next->next;
+  p = curtree.nodep[nonodes2]->next;
   curtree.nodep[nonodes2]->next = curtree.nodep[nonodes2];
+  free(p->next);
   free(p);
   allocrest();
   
@@ -586,6 +587,7 @@ int main(int argc, Char *argv[])
   FClose(outfile);
   FClose(outtree);
   freerest();
+  freetree(&curtree.nodep, nonodes2+1);
 #ifdef MAC
   fixmacfile(outfilename);
   fixmacfile(outtreename);
