@@ -4,11 +4,11 @@
    and Dan Fineman.
    Permission is granted to copy and use this program provided no fee is
    charged for it and provided that this copyright notice is not removed. */
-
+/*
 #ifdef OSX_CARBON
 #include <Carbon/Carbon.h>
-#endif /* OSX_CARBON */
-
+#endif // OSX_CARBON 
+*/
 #include <stdio.h>
 #include <signal.h>
 
@@ -32,9 +32,11 @@ void phyFillScreenColor();
 static void crash_handler(int signum);
 
 #endif
+/*
 #if defined(OSX_CARBON) && defined(__MWERKS__)
 boolean fixedpath = false;
 #endif
+*/
 FILE *outfile, *infile, *intree, *intree2, *outtree, *weightfile, *catfile, *ancfile, *mixfile, *factfile;
 long spp, words, bits;
 boolean ibmpc, ansi, tranvsp;
@@ -119,6 +121,7 @@ void init(int argc, char** argv)
   /* Set default terminal characteristics */
   ibmpc = IBMCRT;
   ansi = ANSICRT;
+  javarun = false;
 
   /* Clear the screen */
   cleerhome();
@@ -241,23 +244,24 @@ void openfile(FILE **fp,const char *filename,const char *filedesc,
   char ch;
   const char *progname_without_path;
   long loopcount, loopcount2;
+  /*
 #if defined(OSX_CARBON) && defined(__MWERKS__)
   ProcessSerialNumber myProcess;
   FSRef bundleLocation;
   unsigned char bundlePath[FNMLNGTH];
   
   if(!fixedpath){
-    /* change path to the bundle location instead of root directory */
+    // change path to the bundle location instead of root directory 
     GetCurrentProcess(&myProcess);
     GetProcessBundleLocation(&myProcess, &bundleLocation);
     FSRefMakePath(&bundleLocation, bundlePath, FNMLNGTH);
     chdir((const char*)bundlePath);
-    chdir(".."); /* get out of the .app directory */
+    chdir(".."); // get out of the .app directory 
     
     fixedpath = true;
   }
 #endif
-
+*/
   progname_without_path = get_command_name(application);
 
   strcpy(file, filename);
@@ -1770,13 +1774,13 @@ void processlength(double *valyew, double *divisor, Char *ch,
   *lengthIsNegative = false;
   pointread = false;
   hasExponent = false;
-  exponentIsNegative = -1; // 3 states:  -1 = unassigned, 1 = true, 0 = false
+  exponentIsNegative = -1; /* 3 states: -1 = unassigned, 1 = true, 0 = false */
   exponent = 0;
   *valyew = 0.0;
   *divisor = 1.0;
   getch(ch, parens, treefile);
   if ('+' == *ch)
-    getch(ch, parens, treefile); // ignore leading '+', because "+1.2345" == "1.2345"
+    getch(ch, parens, treefile); /* ignore leading '+', because "+1.2345" == "1.2345" */
   else if ('-' == *ch)
     {
       *lengthIsNegative = true;
@@ -1798,7 +1802,7 @@ void processlength(double *valyew, double *divisor, Char *ch,
     else if ('+' == *ch)
       {
 	if (hasExponent && -1 == exponentIsNegative)
-	  exponentIsNegative = 0; // 3 states:  -1 = unassigned, 1 = true, 0 = false
+	  exponentIsNegative = 0; /* 3 states:  -1 = unassigned, 1 = true, 0 = false */
 	else
 	  {
 	    printf("\n\nERROR: Branch length found with \'+\' in an unexpected place.\n\n");
@@ -1808,7 +1812,7 @@ void processlength(double *valyew, double *divisor, Char *ch,
     else if ('-' == *ch)
       {
 	if (hasExponent && -1 == exponentIsNegative)
-	  exponentIsNegative = 1; // 3 states:  -1 = unassigned, 1 = true, 0 = false
+	  exponentIsNegative = 1; /* 3 states:  -1 = unassigned, 1 = true, 0 = false */
 	else
 	  {
 	    printf("\n\nERROR: Branch length found with \'-\' in an unexpected place.\n\n");
