@@ -7,7 +7,7 @@
    Permission is granted to copy and use this program provided no fee is
    charged for it and provided that this copyright notice is not removed. */
 
-#define VERSION "3.69"
+#define VERSION "3.695"
 
 /* Debugging options */
 /* Define this to disable assertions */
@@ -199,6 +199,7 @@ void phyFillScreenColor(void);
 #include <math.h>
 #include <ctype.h>
 
+/*
 #ifdef MAC
 #ifdef DRAW
 #include "interface.h"
@@ -207,6 +208,7 @@ void phyFillScreenColor(void);
 #endif
 #define getch gettch
 #endif
+*/
 
 /* directory delimiters */
 #ifdef MAC
@@ -316,6 +318,8 @@ MALLOCRETURN    *mymalloc(long);
 /* Lower-triangular format. */
 #define MAT_LOWERTRI    (MAT_LOWER | MAT_MACHINE)
 
+boolean javarun;
+
 typedef long *steptr;
 typedef long longer[6];
 typedef char naym[MAXNCH];
@@ -334,7 +338,7 @@ extern FILE *infile, *outfile,  *intree, *intree2, *outtree,
 extern long spp, words, bits;
 extern boolean ibmpc, ansi, tranvsp;
 extern naym *nayme;                     /* names of species */
-
+boolean firstplotblock; // for debugging BMP output
 
 #define ebcdic          EBCDIC
 
