@@ -61,6 +61,7 @@ void   initpromlnode(node **, node **, node *, long, long, long *, long *,
 void   tymetrav(node *, double *);
 
 void   free_all_protx(long, pointarray);
+void   freegfcategs(void);
 void   maketree(void);
 void   clean_up(void);
 void   reallocsites(void);
@@ -241,7 +242,7 @@ static double jttprobmat[20][20] =
  -0.02003785382406,-0.00593392430159,-0.00965391033612,+0.00743094349652}};
 
 
-/* dcmut version of PAM model from http://www.ebi.ac.uk/goldman-srv/dayhoff/ */
+/* dcmut version of PAM model from  www.ebi.ac.uk/goldman-srv/dayhoff/ */
 static double pameigmat[] =
 {0,-1.93321786301018,-2.20904642493621,-1.74835983874903,
 -1.64854548332072,-1.54505559488222,-1.33859384676989,-1.29786201193594,
@@ -880,6 +881,18 @@ void makeprotfreqs()
 void reallocsites()
 {
   long i;
+  for (i = 0; i < spp; i++)
+  {
+    free(y[i]);
+  }
+  free(enterorder);
+  free(weight);
+  free(category);
+  free(alias);
+  free(aliasweight);
+  free(ally);
+  free(location);
+  
   for (i = 0; i < spp; i++)
     y[i] = (char *)Malloc(sites * sizeof(char));
   enterorder  = (long *)Malloc(spp*sizeof(long));
@@ -893,7 +906,7 @@ void reallocsites()
       category[i] = 1;
   for (i = 0; i < sites; i++)
     weight[i] = 1;
-  makeweights();
+  /* makeweights(); */
 } /* reallocsites */
 
 
@@ -920,6 +933,7 @@ void doinit()
   /* initializes variables */
 
   inputnumbers(&spp, &sites, &nonodes, 1);
+  nonodes2 = nonodes;
   getoptions();
   makeprotfreqs();
   if (printdata)
@@ -1076,19 +1090,19 @@ void makeweights()
      
    for (i = 1; i <= sites; i++) {
     alias[i - 1] = i;
-    ally[i - 1] = 0;
+    ally[i - 1] = 1;
     aliasweight[i - 1] = weight[i - 1];
     location[i - 1] = 0;
   }  
   sitesort2(sites, aliasweight);
   sitecombine2(sites, aliasweight);
   sitescrunch2(sites, 1, 2, aliasweight);
+  endsite = 0;
   for (i = 1; i <= sites; i++) {
-    if (aliasweight[i - 1] > 0)
-      endsite = i;
+    if (ally[i - 1] == i)
+      endsite++;
   }  
   for (i = 1; i <= endsite; i++) {
-    ally[alias[i - 1] - 1] = alias[i - 1];
     location[alias[i - 1] - 1] = i;
   }  
   contribution = (contribarr *) Malloc( endsite*sizeof(contribarr));
@@ -1243,12 +1257,19 @@ void getinput()
     if (njumble > 1)
       setuptree2(&bestree2);
   } 
+  /* printf("in getinput categs: %li rcategs: %li\n", categs, rcategs); */
+  /* if (!firstset) */
+    /* freegfcategs(); */
   grcategs = (categs > rcategs) ? categs : rcategs;
+  /* printf("calling prot_allocx curtree grcategs: %li\n", grcategs); */
   prot_allocx(nonodes, grcategs, curtree.nodep, usertree);
   if (!usertree) {
+    /* printf("calling prot_allocx bestree grcategs: %li\n", grcategs); */
     prot_allocx(nonodes, grcategs, bestree.nodep, 0);
-    if (njumble > 1)
+    if (njumble > 1){
+      /* printf("calling prot_allocx bestree2 grcategs: %li\n", grcategs); */
       prot_allocx(nonodes, grcategs, bestree2.nodep, 0);
+      }
   } 
   prot_makevalues(rcategs, curtree.nodep, endsite, spp, y, alias);
 }  /* getinput */
@@ -1287,6 +1308,20 @@ void prot_freetable(void)
 } /* prot_freetable */
 
 
+void freegfcategs()
+{
+  long i,j;
+  for ( i = 0 ; i < spp ; i++ ) {
+    for (j = 0; j < endsite; j++)
+      free(curtree.nodep[i]->protx[j]);
+    free(curtree.nodep[i]->protx);
+    free(curtree.nodep[i]->underflows);
+    free(curtree.nodep[i]);
+  }
+  /* free(lrsaves); */
+} /* freegfcategs */
+
+
 void prot_inittable()
 {
   /* Define a lookup table. Precompute values and print them out in tables */
@@ -2577,11 +2612,14 @@ void free_all_protx (long nonodes, pointarray treenode)
   long i, j, k;
   node *p;
 
-  /* Zero thru spp are tips, */
+/* printf("in free_all_protx nonodes: %li spp: %li endsite: %li\n", nonodes,
+   spp, endsite); */
+/* Zero thru spp are tips, */
   for (i = 0; i < spp; i++) {
     for (j = 0; j < endsite; j++)
       free(treenode[i]->protx[j]);
     free(treenode[i]->protx);
+    free(treenode[i]->underflows);
   }
    
   /* The rest are rings (i.e. triads) */
@@ -2592,6 +2630,7 @@ void free_all_protx (long nonodes, pointarray treenode)
         for (k = 0; k < endsite; k++)
           free(p->protx[k]);
         free(p->protx);
+        free(p->underflows);
         p = p->next;
       } 
     }  
@@ -2810,11 +2849,15 @@ void maketree()
   if (jumb < njumble)
     return;
   free(contribution);
+  /* printf("freeing nonodes2 curtree.nodep\n"); */
   free_all_protx(nonodes2, curtree.nodep);
   if (!usertree) {
+    /* printf("freeing nonodes2 bestree.nodep\n"); */
     free_all_protx(nonodes2, bestree.nodep);
-    if (njumble > 1)
+    if (njumble > 1){
+      /* printf("freeing nonodes2 bestree2.nodep\n"); */
       free_all_protx(nonodes2, bestree2.nodep);
+      }
   }
   if (progress) {
     printf("\n\nOutput written to file \"%s\"\n", outfilename);
