@@ -330,7 +330,7 @@ void getoptions()
     else
       printf("  No\n");
     printf("  I          Input sequences interleaved?  %s\n",
-           (interleaved ? "Yes" : "No"));
+           (interleaved ? "Yes" : "No, sequential"));
     printf("  0   Terminal type (IBM PC, ANSI, none)?  %s\n",
            (ibmpc ? "IBM PC" : ansi ? "ANSI" : "(none)"));
     printf("  1    Print out the data at start of run  %s\n",
@@ -1852,6 +1852,8 @@ void maketree()
     /* Open in binary: ftell() is broken for UNIX line-endings under WIN32 */
     openfile(&intree,INTREE,"input tree file", "rb",progname,intreename);
     numtrees = countsemic(&intree);
+    if (numtrees > 2)
+      initseed(&inseed, &inseed0, seed);
     if (treeprint) {
       fprintf(outfile, "User-defined tree");
       if (numtrees > 1)
@@ -1876,9 +1878,9 @@ void maketree()
       standev(chars, numtrees, minwhich, minsteps, nsteps, fsteps, seed);
   }
   if (jumb == njumble && progress) {
-    printf("Output written to file \"%s\"\n\n", outfilename);
+    printf("Output written to file \"%s\"\n", outfilename);
     if (trout)
-      printf("Trees also written onto file \"%s\"\n\n", outtreename);
+      printf("\nTrees also written onto file \"%s\"\n", outtreename);
   }
 }  /* maketree */
 
@@ -1926,7 +1928,7 @@ int main(int argc, Char *argv[])
   fixmacfile(outfilename);
   fixmacfile(outtreename);
 #endif
-  printf("Done.\n\n");
+  printf("\nDone.\n\n");
 
 #ifdef WIN32
   phyRestoreConsoleAttributes();
