@@ -387,7 +387,7 @@ void getoptions()
     uppercase(&ch);
     if (ch == 'Y')
       break;
-    if (((!usertree) && (strchr("UNASGJOTMI01234", ch) != NULL))
+    if (((!usertree) && (strchr("UNASGJLOTMI01234", ch) != NULL))
           || (usertree && ((strchr("UNASLOTMI01234", ch) != NULL)))){
       switch (ch) {
 
