@@ -166,7 +166,7 @@ void getoptions()
     if (data == genefreqs)
       printf("  A       All alleles present at each locus?  %s\n",
              all ? "Yes" : "No, one absent at each locus");
-    if (data == morphology)
+    if ((!lockhart) && (data == morphology))
       printf("  F                 Use factors information?  %s\n",
            factors ? "Yes" : "No");
 
@@ -258,7 +258,7 @@ void getoptions()
         (bootstrap && (strchr("ABCDEFSJPRWXNI%1.20",ch) != NULL)) ||
         (jackknife && (strchr("ACDEFSJPRWXNI%1.20",ch) != NULL)) ||
         (permute && (strchr("ACDEFSJPRWXNI%1.20",ch) != NULL)) ||
-        ((ild || lockhart) && (strchr("ACDEFSJPRXNI%1.20",ch) != NULL)) ||
+        ((ild || lockhart) && (strchr("ACDESJPRXNI%1.20",ch) != NULL)) ||
         ((!(bootstrap || jackknife || permute || ild || lockhart)) &&
          ((!xml) && (strchr("ADEFJPI1.20",ch) != NULL))) ||
         (((data == morphology) || (data == seqs))
@@ -294,7 +294,6 @@ void getoptions()
       } else if (ild) {
         ild = false;
         lockhart = true;
-        factors = false;
       } else if (lockhart) {
         lockhart = false;
         rewrite = true;
